@@ -23,7 +23,7 @@ License: Python Software Foundation License
 """
 
 
-import os, urllib, string, inspect
+import os, urllib, inspect
 import hmac, hashlib, base64
 from xml.dom import minidom
 from time import gmtime, strftime
@@ -224,7 +224,6 @@ def buildException(els):
 
 
 def query(url):
-	print url
 	"""Send the query url and return the DOM
 	
 	Exception is raised if there is errors"""
@@ -281,7 +280,7 @@ class pagedIterator(object):
 		self.__items = unmarshal(dom.getElementsByTagName(kwItems).item(0), plugins, wrappedIterator())
 		try:
 			self.__len = int(dom.getElementsByTagName("TotalResults").item(0).firstChild.data)
-		except AttributeError, e:
+		except AttributeError:
 			self.__len = len(self.__items)
 
 	def __len__(self):
@@ -387,7 +386,7 @@ def ItemLookup(ItemId, IdType=None, SearchIndex=None, MerchantId=None, Condition
 def XMLItemLookup(ItemId, IdType=None, SearchIndex=None, MerchantId=None, Condition=None, DeliveryMethod=None, ISPUPostalCode=None, OfferPage=None, ReviewPage=None, VariationPage=None, ResponseGroup=None, AWSAccessKeyId=None): 
 	'''DOM representation of ItemLookup in ECS'''
 
-	Operation = "ItemLookup"
+	Operation = "ItemLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -406,7 +405,7 @@ def ItemSearch(Keywords, SearchIndex="Blended", Availability=None, Title=None, P
 def XMLItemSearch(Keywords, SearchIndex="Blended", Availability=None, Title=None, Power=None, BrowseNode=None, Artist=None, Author=None, Actor=None, Director=None, AudienceRating=None, Manufacturer=None, MusicLabel=None, Composer=None, Publisher=None, Brand=None, Conductor=None, Orchestra=None, TextStream=None, ItemPage=None, Sort=None, City=None, Cuisine=None, Neighborhood=None, MinimumPrice=None, MaximumPrice=None, MerchantId=None, Condition=None, DeliveryMethod=None, ResponseGroup=None, AWSAccessKeyId=None):  
 	'''DOM representation of ItemSearch in ECS'''
 
-	Operation = "ItemSearch"
+	Operation = "ItemSearch" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -425,7 +424,7 @@ def SimilarityLookup(ItemId, SimilarityType=None, MerchantId=None, Condition=Non
 def XMLSimilarityLookup(ItemId, SimilarityType=None, MerchantId=None, Condition=None, DeliveryMethod=None, ResponseGroup=None, AWSAccessKeyId=None):  
 	'''DOM representation of SimilarityLookup in ECS'''
 
-	Operation = "SimilarityLookup"
+	Operation = "SimilarityLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -446,7 +445,7 @@ def ListLookup(ListType, ListId, ProductPage=None, ProductGroup=None, Sort=None,
 def XMLListLookup(ListType, ListId, ProductPage=None, ProductGroup=None, Sort=None, MerchantId=None, Condition=None, DeliveryMethod=None, ResponseGroup=None, AWSAccessKeyId=None):  
 	'''DOM representation of ListLookup in ECS'''
 
-	Operation = "ListLookup"
+	Operation = "ListLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -465,7 +464,7 @@ def ListSearch(ListType, Name=None, FirstName=None, LastName=None, Email=None, C
 def XMLListSearch(ListType, Name=None, FirstName=None, LastName=None, Email=None, City=None, State=None, ListPage=None, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of ListSearch in ECS'''
 
-	Operation = "ListSearch"
+	Operation = "ListSearch" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -482,7 +481,7 @@ def CartCreate(Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLCartCreate(Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CartCreate in ECS'''
 
-	Operation = "CartCreate"
+	Operation = "CartCreate" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	for x in ('Items', 'Quantities'):
@@ -502,10 +501,10 @@ def CartAdd(Cart, Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLCartAdd(Cart, Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CartAdd in ECS'''
 
-	Operation = "CartAdd"
+	Operation = "CartAdd" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
-	CartId = Cart.CartId
-	HMAC = Cart.HMAC
+	CartId = Cart.CartId #@UnusedVariable
+	HMAC = Cart.HMAC #@UnusedVariable
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	for x in ('Items', 'Cart', 'Quantities'):
 		del argv[x]
@@ -523,10 +522,10 @@ def CartGet(Cart, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLCartGet(Cart, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CartGet in ECS'''
 
-	Operation = "CartGet"
+	Operation = "CartGet" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
-	CartId = Cart.CartId
-	HMAC = Cart.HMAC
+	CartId = Cart.CartId #@UnusedVariable
+	HMAC = Cart.HMAC #@UnusedVariable
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	del argv['Cart']
 	return query(buildRequest(argv, SECRET_KEY))
@@ -541,10 +540,10 @@ def CartModify(Cart, Items, Actions, ResponseGroup=None, AWSAccessKeyId=None):
 
 def XMLCartModify(Cart, Items, Actions, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CartModify in ECS'''
-	Operation = "CartModify"
+	Operation = "CartModify" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
-	CartId = Cart.CartId
-	HMAC = Cart.HMAC
+	CartId = Cart.CartId #@UnusedVariable
+	HMAC = Cart.HMAC #@UnusedVariable
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	for x in ('Cart', 'Items', 'Actions'):
 		del argv[x]
@@ -562,10 +561,10 @@ def CartClear(Cart, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLCartClear(Cart, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CartClear in ECS'''
 
-	Operation = "CartClear"
+	Operation = "CartClear" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
-	CartId = Cart.CartId
-	HMAC = Cart.HMAC
+	CartId = Cart.CartId #@UnusedVariable
+	HMAC = Cart.HMAC #@UnusedVariable
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	del argv['Cart']
 
@@ -607,9 +606,9 @@ def SellerLookup(Sellers, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLSellerLookup(Sellers, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of SellerLookup in AWS'''
 
-	Operation = "SellerLookup"
+	Operation = "SellerLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
-	SellerId = ",".join(Sellers)
+	SellerId = ",".join(Sellers) #@UnusedVariable
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	del argv['Sellers']
 	return query(buildRequest(argv, SECRET_KEY))
@@ -632,7 +631,7 @@ def SellerListingLookup(SellerId, Id, IdType="Listing", ResponseGroup=None, AWSA
 def XMLSellerListingLookup(SellerId, Id, IdType="Listing", ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of SellerListingLookup in AWS'''
 
-	Operation = "SellerListingLookup"
+	Operation = "SellerListingLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -651,7 +650,7 @@ def SellerListingSearch(SellerId, Title=None, Sort=None, ListingPage=None, Offer
 def XMLSellerListingSearch(SellerId, Title=None, Sort=None, ListingPage=None, OfferStatus=None, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of SellerListingSearch in AWS'''
 
-	Operation = "SellerListingSearch"
+	Operation = "SellerListingSearch" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -670,7 +669,7 @@ def CustomerContentSearch(Name=None, Email=None, CustomerPage=1, ResponseGroup=N
 def XMLCustomerContentSearch(Name=None, Email=None, CustomerPage=1, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CustomerContentSearch in AWS'''
 
-	Operation = "CustomerContentSearch"
+	Operation = "CustomerContentSearch" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	for x in ('Name', 'Email'):
@@ -692,7 +691,7 @@ def CustomerContentLookup(CustomerId, ReviewPage=1, ResponseGroup=None, AWSAcces
 def XMLCustomerContentLookup(CustomerId, ReviewPage=1, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of CustomerContentLookup in AWS'''
 
-	Operation = "CustomerContentLookup"
+	Operation = "CustomerContentLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -712,7 +711,7 @@ def BrowseNodeLookup(BrowseNodeId, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLBrowseNodeLookup(BrowseNodeId, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of BrowseNodeLookup in AWS'''
 	
-	Operation = "BrowseNodeLookup"
+	Operation = "BrowseNodeLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -734,7 +733,7 @@ def Help(HelpType, About, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLHelp(HelpType, About, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of Help in AWS'''
 
-	Operation = "Help"
+	Operation = "Help" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
@@ -755,7 +754,7 @@ def TransactionLookup(TransactionId, ResponseGroup=None, AWSAccessKeyId=None):
 def XMLTransactionLookup(TransactionId, ResponseGroup=None, AWSAccessKeyId=None):
 	'''DOM representation of TransactionLookup in AWS'''
 
-	Operation = "TransactionLookup"
+	Operation = "TransactionLookup" #@UnusedVariable
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	return query(buildRequest(argv, SECRET_KEY))
