@@ -45,7 +45,7 @@ more like Vorbis or APEv2 tags.
 import mutagen.id3
 from mutagen import Metadata
 from mutagen._util import DictMixin
-from mutagen.id3 import ID3 as mutagenID3, error, delete
+from mutagen.id3 import ID3 as mutagenID3, error
 from mutagen.mp3 import MP3
 
 __all__ = ['EasyID3', 'Open', 'delete']
