@@ -23,9 +23,7 @@
 
 
 import gobject
-import os
-from config import config
-from threading import Condition, Thread
+from threading import Condition
 import utils
 import time
 from random import shuffle
@@ -213,7 +211,7 @@ class ListenDatabase(gobject.GObject,Logger):
     def set_force_sanity_check(self):
         self.__force_sanity_check = True
 
-    @utils.threaded
+#    @utils.threaded
     def load(self):
         self.loginfo("Loading library...")
 
@@ -234,7 +232,7 @@ class ListenDatabase(gobject.GObject,Logger):
             update_window.set_nb_items(len(db_objs) + len(pls_objs))
             update_window.show_all()
             gtk.gdk.threads_leave()
-
+        
         if db_objs:
             for obj in db_objs:
                 try: stype = obj["==song_type=="]
@@ -245,8 +243,12 @@ class ListenDatabase(gobject.GObject,Logger):
                 if stype not in self.__song_types: 
                     self.logwarn("Song type %s not exist, force registration", stype)
                     self.register_type(stype)
-
-                s = Song(obj)
+                
+                if self.__force_sanity_check:
+                    s = Song()
+                    s.sanitarize_init_from_dict(obj)
+                else:
+                    s = Song(obj)
                 s.set_type(stype)
                 if self.__force_sanity_check:
                     s["uri"] = vfs.realuri(s.get("uri"))
@@ -254,7 +256,7 @@ class ListenDatabase(gobject.GObject,Logger):
                     self.__hiddens.remove(s)
                     del self.__songs[s.get("uri")]
                 if not self.__force_sanity_check or not self.__songs.has_key(s.get("uri")):
-                    self.add([s], self.__force_sanity_check)
+                    self.add([s])
                     if self.__force_sanity_check:
                         gtk.gdk.threads_enter()
                         update_window.update()
@@ -372,7 +374,7 @@ class ListenDatabase(gobject.GObject,Logger):
             del self.__db_wrapper[name]
             del self.__db_wrapper_load[name]
         except KeyError:
-             self.logwarn("Unregister a unknown type wrapper \"%s\"",name)
+            self.logwarn("Unregister a unknown type wrapper \"%s\"",name)
 
     def register_playlist_type(self, name):
         if name not in self.__playlist_types:
@@ -401,7 +403,7 @@ class ListenDatabase(gobject.GObject,Logger):
     def request(self,type, string):
         try: 
             filter = Query(string).search
-        except Query.error:
+        except Query.error: #@UndefinedVariable
             self.loginfo("Request: Query error %s", string )
             return None
         else:
@@ -416,9 +418,8 @@ class ListenDatabase(gobject.GObject,Logger):
         self.remove(songs)
         self.add(songs)
 
-    def add(self, songs, sanitarize=True):
+    def add(self, songs):
         for song in songs:
-            if sanitarize: song.sanitarize()
             type = song.get_type()
             if not self.__db_wrapper.has_key(type) or self.__db_wrapper_load[type]:
                 self.__add_cb(song)
@@ -480,7 +481,6 @@ class ListenDatabase(gobject.GObject,Logger):
         [ old_keys_values.update({key:song.get_sortable(key)}) for key in song.keys() if key in mod_keys]
         [ song.update({key:value}) for key, value in keys_values.items() if value is not None]
         for key in [ key for key, value in keys_values.items() if value is None ]: del song[key]
-        song.sanitarize()
         if write_to_file: ret = song.write_to_file()
         self.__condition.acquire()
         if use_quick_update:
@@ -499,17 +499,16 @@ class ListenDatabase(gobject.GObject,Logger):
         old_keys_values = {}
         [ old_keys_values.update({key:song.get_sortable(key)}) for key in song.keys() if key in keys]
         for key in keys: del song[key]
-        song.sanitarize()
         self.__condition.acquire()
         self.__queued_signal["changed"].setdefault(type, [])
         self.__queued_signal["changed"][type].append((song, old_keys_values))
         self.__condition.release()
         
     def reload_song_from_file(self, song):
-        s = Song({"uri":song.get("uri")})
+        s = Song()
+        s.sanitarize_init_from_dict({"uri":song.get("uri")})
         s["uri"] = vfs.realuri(s.get("uri"))
         s.read_from_file()
-        s.sanitarize()
         new_tags = {}
         for key in TAG_KEYS.values()+["#size", "#mtime", "#ctime"]:
             if s.has_key(key) and not song.has_key(key):
@@ -522,17 +521,19 @@ class ListenDatabase(gobject.GObject,Logger):
     
     def create_song(self, tags, type, read_from_file=False):
         self._dirty = True
-        try: uri = tags["uri"]
-        except KeyError: raise MissingUriTag()
-        tags["uri"] = vfs.realuri(tags["uri"])
+        try: 
+            uri = tags["uri"]
+        except KeyError: 
+            raise MissingUriTag()
+        tags["uri"] = vfs.realuri(uri)
         return self.__create_song(tags, type, read_from_file=read_from_file)
 
     def __create_song(self, tags, type, hidden=False, read_from_file=False):
-        s = Song(tags)
+        s = Song()
+        s.sanitarize_init_from_dict(tags)
         s.set_type(type)
         if read_from_file: s.read_from_file()
         if hidden:
-            s.sanitarize()
             self.__db_operation_lock.acquire()
             self.__songs[tags["uri"]] = s
             self.__db_operation_lock.release()
@@ -777,7 +778,7 @@ class ListenDBQuery(gobject.GObject,Logger):
         if string:
             try: 
                 query_func = Query(string).search
-            except Query.error :
+            except Query.error : #@UndefinedVariable
                 self.loginfo("Query error %s, %d song cached (%f)", string, len(self.__tree[1]), (time.time()-deb) )
                 return
             self.empty()
@@ -1005,7 +1006,7 @@ class ListenDBQuery(gobject.GObject,Logger):
                 for key, info in mydict.iteritems():
                     if key == "###ALL###": continue
                     if extended_info:
-                        title, playcount, duration, songs = infos.get(key,(info[2], 0, 0, []))
+                        _title, playcount, duration, songs = infos.get(key,(info[2], 0, 0, []))
                         playcount += sum(s.get("#playcount", 0) for s in info[1])
                         duration += sum(s.get("#duration", 0) for s in info[1])
                         songs.extend(info[1])
@@ -1030,7 +1031,7 @@ class ListenDBQuery(gobject.GObject,Logger):
                         for key, info in mydict.iteritems():
                             if key == "###ALL###": continue
                             if extended_info:
-                                title, playcount, duration, songs = infos.get(key,(info[2], 0, 0, []))
+                                _title, playcount, duration, songs = infos.get(key,(info[2], 0, 0, []))
                                 playcount += sum(s.get("#playcount", 0) for s in info[1])
                                 duration += sum(s.get("#duration", 0) for s in info[1])
                                 songs.extend(info[1])
@@ -1056,7 +1057,7 @@ class ListenDBQuery(gobject.GObject,Logger):
                                 for key, info in mydict.iteritems():
                                     if key == "###ALL###": continue
                                     if extended_info:
-                                        title, playcount, duration, songs = infos.get(key,(info[2], 0, 0, []))
+                                        _title, playcount, duration, songs = infos.get(key,(info[2], 0, 0, []))
                                         playcount += sum(s.get("#playcount", 0) for s in info[1])
                                         duration += sum(s.get("#duration", 0) for s in info[1])
                                         songs.extend(info[1])
@@ -1106,7 +1107,11 @@ class AutoPlaylist(ListenDBQuery):
             ListenDB.connect("loaded", self.__on_db_loaded)
 
     def set_name(self,name):
-        self.name = name 
+        if self.name == name:
+            return False
+        else:
+            self.name = name
+            return True
 
     def get_name(self):
         return self.name
@@ -1148,8 +1153,9 @@ class AutoPlaylist(ListenDBQuery):
     def prepare_rules(self):
         ListenDB.set_dirty()
 
-        try: filter = Query(self.rules["string"]).search
-        except Query.error: 
+        try: 
+            filter = Query(self.rules["string"]).search
+        except Query.error:  #@UndefinedVariable
             self.logexception("Automated playlist query failed: %s",self.rules["string"])
             return 
 
@@ -1168,11 +1174,11 @@ class AutoPlaylist(ListenDBQuery):
         if self.rules["has_limit"]:
             if self.rules["limit_type"] == "title":
                 tmp = tmp[:self.rules["limit"]]
-                songs = [s for sort_field, sort_key, size, duration, s in tmp]
+                songs = [s for _sort_field, _sort_key, size, duration, s in tmp]
                 
             elif self.rules["limit_type"] == "duration":
                 total_duration = 0
-                for order_field, sort_key, size, duration, s in tmp:
+                for _order_field, _sort_key, size, duration, s in tmp:
                     total_duration += duration   
                     print total_duration 
                     if total_duration < self.rules["limit"]*60*1000:
@@ -1183,7 +1189,7 @@ class AutoPlaylist(ListenDBQuery):
             elif self.rules["limit_type"] in [ "mo", "go" ]:
                 total_size = 0
                 unit = {"mo":1024*1024, "go":1024*1024*1024 }[self.rules["limit_type"]]
-                for order_field, sort_key, size, duration, s in tmp:
+                for _order_field, _sort_key, size, duration, s in tmp:
                     total_size += size
                     if total_size < self.rules["limit"]*unit:
                         songs.append(s) 
@@ -1192,7 +1198,7 @@ class AutoPlaylist(ListenDBQuery):
             else:
                 self.logerror("smart playlist %s have limit type '%s' unsupported ", self.name, self.rules["limit_type"] )
         else:
-            songs = [ s for sort_field, sort_key, size, duration, s in tmp]
+            songs = [ s for _sort_field, _sort_key, size, duration, s in tmp]
         
         self.__cached_songs = set(songs)
         self.loginfo("smart playlist %s prepartion done (len: %d)",self.name, len(self.__cached_songs))
