@@ -27,12 +27,12 @@ class MyFilter(logging.Filter):
         return False
 
 
-FORMAT="%(levelname)-8s %(name)s   %(message)s"
-logger = logging.getLogger("listen")
+logger = logging.getLogger("")
 logger.setLevel(logging.DEBUG)
 logging.addLevelName(100,"DEPRECATED")
 
-formatter = logging.Formatter(FORMAT)
+#formatter = logging.Formatter('%(asctime)s %(levelname)-8s %(name)-30s %(message)s')
+formatter = logging.Formatter('%(levelname)-8s %(name)-30s %(message)s')
 
 handler = logging.StreamHandler()
 handler.setFormatter(formatter)
@@ -42,48 +42,60 @@ handler.addFilter(MyFilter())
 logger.addHandler(handler)
 
 def objaddr(obj):
-    string = "%s"%obj
+    string = object.__repr__(obj)
     m = re.search("at (0x\w+)",string)
-    if m: return  m.group(1)
-    m = re.search("/GstPipeline:ListenPlayer/GstBin:(\w+) \(StreamBin\)",string)
-    if m: return m.group(1)
-    return ""
+    if m: return  m.group(1)[2:]
+    return "       "
 
-def newLogger(name):
-    return logging.getLogger("listen.%s"%name)
 
 class Logger(object):
+
+    def set_logname(self, name):
+        self.__logname = name
+
+    def get_logname(self):
+        if hasattr(self,"__logname") and self.__logname :
+            return self.__logname
+        else:
+            return "%s.%s"%(self.__module__,self.__class__.__name__)
+
     def logdebug(self, msg, *args, **kwargs): 
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.debug(msg, *args, **kwargs)
 
     def loginfo(self, msg, *args, **kwargs): 
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.info(msg, *args, **kwargs)
 
     def logwarn(self, msg, *args, **kwargs): 
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.warn(msg, *args, **kwargs)
 
     def logerror(self, msg, *args, **kwargs): 
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.error(msg, *args, **kwargs)
 
     def logcritical(self, msg, *args, **kwargs): 
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.critical(msg, *args, **kwargs)
 
     def logexception(self, msg, *args, **kwargs):
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.exception(msg, *args, **kwargs)
 
     def logdeprecated(self, msg, *args, **kwargs):
         msg = "%s  %s"%(objaddr(self),msg)
-        mylogger = logging.getLogger("listen.%s.%s"%(self.__module__,self.__class__.__name__))
+        mylogger = logging.getLogger(self.get_logname())
         mylogger.log(100,msg, *args, **kwargs)
+
+def newLogger(name):
+    l = Logger()
+    l.set_logname(name)
+    return l
+
