@@ -22,7 +22,6 @@
 
 
 import os
-from helper import Dispatcher
 
 from logger import Logger
 
@@ -39,47 +38,47 @@ class MMKeys(Logger):
         self.use = self.__use_gnome() or self.__use_mmkeys()
         self.loginfo("MMKeys mode: %s",self.use)
     
+    def on_gnome_mmkey(self, app, key):
+        if app == self.application:
+            if key == "Play":
+                Player.playpause()
+            if key == "PlayPause":
+                Player.playpause()
+            if key == "Stop":
+                Player.stop()
+            if key == "Next":
+                Player.next()
+            if key == "Previous":
+                Player.previous()
+                
     def __use_gnome(self):
-        def on_gnome_mmkey(app, key):
-            if app == self.application:
-                if key == "Play":
-                    Player.playpause()
-                if key == "PlayPause":
-                    Player.playpause()
-                if key == "Stop":
-                    Player.stop()
-                if key == "Next":
-                    Player.next()
-                if key == "Previous":
-                    Player.previous()
-        
-
-	try:
-		# Gnome >= 2.22.X
-        	import dbus
-        	bus = dbus.SessionBus()
-        	obj = bus.get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon/MediaKeys')
-        	self.__gnome = dbus.Interface(obj, 'org.gnome.SettingsDaemon.MediaKeys')
-        	self.__gnome.GrabMediaPlayerKeys(self.application, 0)
-        	self.__gnome.connect_to_signal("MediaPlayerKeyPressed", on_gnome_mmkey)
-	except:
-		try:
-			# Gnome < 2.22.X
-			import dbus
-			bus = dbus.SessionBus()
-			obj = bus.get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon')
-			self.__gnome = dbus.Interface(obj, 'org.gnome.SettingsDaemon')
-			self.__gnome.GrabMediaPlayerKeys(self.application, 0)
-			self.__gnome.connect_to_signal("MediaPlayerKeyPressed", on_gnome_mmkey)
-		except:
-			return None
-        
-        return 'gnome'
-    
-    def __use_mmkeys(self):
-        try:import mmkeys
+        try:
+            # Gnome >= 2.22.X
+                import dbus
+                bus = dbus.SessionBus()
+                obj = bus.get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon/MediaKeys')
+                self.__gnome = dbus.Interface(obj, 'org.gnome.SettingsDaemon.MediaKeys')
+                self.__gnome.GrabMediaPlayerKeys(self.application, 0)
+                self.__gnome.connect_to_signal("MediaPlayerKeyPressed", self.on_gnome_mmkey)
         except:
-        	return None
+            try:
+                # Gnome < 2.22.X
+                import dbus #@Reimport
+                bus = dbus.SessionBus()
+                obj = bus.get_object('org.gnome.SettingsDaemon', '/org/gnome/SettingsDaemon')
+                self.__gnome = dbus.Interface(obj, 'org.gnome.SettingsDaemon')
+                self.__gnome.GrabMediaPlayerKeys(self.application, 0)
+                self.__gnome.connect_to_signal("MediaPlayerKeyPressed", self.on_gnome_mmkey)
+            except:
+                return None
+            
+        return 'gnome'
+        
+    def __use_mmkeys(self):
+        try:
+            import mmkeys #@UnresolvedImport
+        except:
+            return None
         
         self.__keys = mmkeys.MmKeys()
         self.__keys.connect("mm_prev", self.mm_previous)
@@ -90,15 +89,15 @@ class MMKeys(Logger):
         return 'mmkeys'
         
     def release(self):
-    	if self.use == 'gnome':
-    		self.__gnome.ReleaseMediaPlayerKeys(self.application)
+        if self.use == 'gnome':
+            self.__gnome.ReleaseMediaPlayerKeys(self.application)
     
     def mm_play(self,a,b):
-    	Player.play()
-    	
+        Player.play()
+        
     def mm_next(self,a,b):
-    	Player.next()
-    	
+        Player.next()
+        
     def mm_previous(self,a,b):
-    	Player.previous()
+        Player.previous()
     
