@@ -51,15 +51,16 @@ class Plugin(Logger):
         if self.signal_collector_id:
             SignalCollector.connect(self.signal_collector_id,obj,signal_name,func,*args)
 
-    def destroy(self):
+    def delete_thyself(self):
         if self.signal_collector_id:
+            self.logdebug("disconnect monitored signal for %s"%self.signal_collector_id)
             SignalCollector.disconnect_all(self.signal_collector_id)
 
     """
     Require to enable configure button in preferences
     Need to be static
     @staticmethod
-    def on_configure(parent):
+    def on_configure():
         pass
     """
 
@@ -151,38 +152,40 @@ class Manager(gobject.GObject):
         self._plugins[name] = objs
 
     def find_subclasses(self, Kind, all=False):
-         """Return all classes in all plugins that subclass 'Kind'."""
-         kinds = []
-         for plugin in self._plugins.values():
-             for obj in plugin:
-                 try:
-                     if issubclass(obj, Kind) and obj is not Kind:
-                         kinds.append(obj)
-                 except TypeError: pass
- 
-         for Kind in kinds:
-             try: Kind.PLUGIN_ID
-             except AttributeError:
-                 try: Kind.PLUGIN_ID = Kind.PLUGIN_NAME
-                 except AttributeError:
-                     Kind.PLUGIN_ID = Kind.__name__
- 
-             try: Kind.PLUGIN_NAME
-             except AttributeError:
-                 Kind.PLUGIN_NAME = Kind.PLUGIN_ID
-                 
-             try: Kind.PLUGIN_DESC
-             except AttributeError:
-                 Kind.PLUGIN_DESC = ""
-                 
-             try: Kind.PLUGIN_VERSION
-             except AttributeError:
-                 Kind.PLUGIN_VERSION = "0.0"
- 
-         if not all:
-             kinds = filter(self.enabled, kinds)
- 
-         return kinds
+        """Return all classes in all plugins that subclass 'Kind'."""
+        kinds = []
+        for plugin in self._plugins.values():
+            for obj in plugin:
+                try:
+                    if issubclass(obj, Kind) and obj is not Kind:
+                        kinds.append(obj)
+                except TypeError: pass
+
+        for Kind in kinds:
+            try: Kind.PLUGIN_ID
+            except AttributeError:
+                try: Kind.PLUGIN_ID = Kind.PLUGIN_NAME
+                except AttributeError:
+                    Kind.PLUGIN_ID = Kind.__name__
+
+            try: Kind.PLUGIN_NAME
+            except AttributeError:
+                Kind.PLUGIN_NAME = Kind.PLUGIN_ID
+                
+            try: Kind.PLUGIN_DESC
+            except AttributeError:
+                Kind.PLUGIN_DESC = ""
+                
+            try: Kind.PLUGIN_VERSION
+            except AttributeError:
+                Kind.PLUGIN_VERSION = "0.0"
+
+        if not all:
+            kinds = filter(self.enabled, kinds)
+
+        return kinds
+
+
 
     def enable(self, plugin, enabled,emit=True):
         plugin.__enabled = bool(enabled)
