@@ -38,15 +38,20 @@ class BraseroPlugin(GenericPlugin):
     def __init__(self):
         GenericPlugin.__init__(self)
 
-        def song_menu_action(song_menu_manager,id_menu,songs):
+        def song_menu_action(song_menu_manager, id_menu, songs):
             if id_menu == "brasero" and songs:
                 uris = [ get_path_from_uri(song.get("uri")) for song in songs ]
-                Popen("brasero -a '%s'"%"' '".join(uris) , shell=True)
+                Popen("brasero -a '%s'" % "' '".join(uris) , shell=True)
 
-        self.autoconnect(SongMenuManager,"action",song_menu_action)
+        self.autoconnect(SongMenuManager, "action", song_menu_action)
         SongMenuManager.register_item("brasero", 85,
-                add_stock("brasero", _("Burn this track to audio CD"), WIKI_CD) )
-        for type in [ "local","unknown_local"]:
-            SongMenuManager.allow_item_for_type("brasero",type)
+                add_stock("brasero", _("Burn this track to audio CD"), WIKI_CD))
+        for type in [ "local", "unknown_local"]:
+            SongMenuManager.allow_item_for_type("brasero", type)
+
+    def delete_thyself(self):
+        SongMenuManager.unregister_item("brasero")
+        for type in [ "local", "unknown_local"]:
+            SongMenuManager.disallow_item_for_type("brasero", type)
+        super(BraseroPlugin, self).delete_thyself()
 
-        
