@@ -25,18 +25,16 @@
 
 
 import os
-import sys
 import re
 
 import gobject
-import gtk
-import gst
 
 try:
-    import avahi, dbus
-    import dbus.glib
+    import avahi
+    import dbus 
+    import dbus.glib #@UnusedImport
 except ImportError: dbus_imported = False
-else: dbus_imported=True
+else: dbus_imported = True
 
 from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer
 
@@ -44,13 +42,10 @@ from config import config
 
 from xdg_support import get_xdg_cache_dir
 from plugins.generic import GenericPlugin
-from player import Player
-from widget.preference import HelperConfigureDialog
-from helper import Dispatcher
 from logger import Logger
 
 from library import ListenDB
-from vfs import get_path_from_uri, makedirs
+from vfs import get_path_from_uri
 
 from hashlib import md5
 
@@ -129,11 +124,11 @@ class ContainerCache(cache.OrderedCache):
                      do('dmap.itemid', md.id),
                      do('dmap.itemname', md.get_name()),
                      do('dmap.containeritemid', id)
-                     ] )
+                     ])
             return d
         pid_list = []
         for pl in ListenDB.get_playlists("local"):
-            entries = [ md_cache.get_item_by_pid( md5( get_path_from_uri(song.get("uri")) ).hexdigest() ) 
+            entries = [ md_cache.get_item_by_pid(md5(get_path_from_uri(song.get("uri"))).hexdigest()) 
                             for song in pl.get_songs()]
 
             #FIXME: For now i remove not cached song inteads of metadata
@@ -144,7 +139,7 @@ class ContainerCache(cache.OrderedCache):
                      do('dmap.specifiedtotalcount', len(entries)),
                      do('dmap.returnedcount', len(entries)),
                      do('dmap.listing',
-                        [ build_do (md,id) for (id, md) in enumerate(entries) ])
+                        [ build_do (md, id) for (id, md) in enumerate(entries) ])
                      ])
             ContainerCacheItem.write_entry(self.dir, str(pl.get_name()), d, len(entries))
             pid_list.append(md5(pl.name).hexdigest())
@@ -159,6 +154,7 @@ class MetadataCache(cache.OrderedCache):
         songs = ListenDB.get_songs("local")
         for song in songs:
             ffn = get_path_from_uri(song.get("uri"))
+            if not os.path.exists(ffn): continue
             digest = md5(ffn).hexdigest()
             marked[digest] = True
             md = self.get_item_by_pid(digest)
@@ -166,13 +162,13 @@ class MetadataCache(cache.OrderedCache):
                     (md.get_mtime() < os.stat(ffn).st_mtime)):
                 m = self.parse(song)
                 if m != None:
-                    MetadataCacheItem.write_entry(self.dir,str( song.get_str("title")), ffn, m)
+                    MetadataCacheItem.write_entry(self.dir, str(song.get_str("title")), ffn, m)
         for item in os.listdir(self.dir):
             if (len(item) == 32) and not(marked.has_key(item)):
                 os.remove(os.path.join (self.dir, item))
         self.build_index()
 
-    def parse(self,song):
+    def parse(self, song):
         tag_map = {
         #'TIT1': 'daap.songgrouping',
         'title': 'dmap.itemname',
@@ -196,7 +192,7 @@ class MetadataCache(cache.OrderedCache):
                 d.append(do(mkey, int(str(tag))))
             else:
                 tag = song.get(key)
-                d.append(do(mkey, str(tag) ))
+                d.append(do(mkey, str(tag)))
         d.extend([
                 do("daap.songformat", "mp3"),
                 do('daap.songdescription', 'MPEG Audio File'),
@@ -204,25 +200,25 @@ class MetadataCache(cache.OrderedCache):
         return d
 
 
-class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
+class DaapRequestHandler(BaseHTTPRequestHandler, Logger):
     session_id = 1
     server_revision = 1
     def do_GET(self):
-        for i in range(0, len(urls), 2 ):
-            res = re.match("^"+itunes_re+urls[i]+drop_q+"$",self.path)
+        for i in range(0, len(urls), 2):
+            res = re.match("^" + itunes_re + urls[i] + drop_q + "$", self.path)
             if res is not None:
                 args = res.groups()
-                self.loginfo("'%s' match '%s' call: %s%s",self.path, urls[i], urls[i+1],args)
-                if hasattr(self,urls[i+1]):
-                    getattr(self, urls[i+1])(*args)
+                self.loginfo("'%s' match '%s' call: %s%s", self.path, urls[i], urls[i + 1], args)
+                if hasattr(self, urls[i + 1]):
+                    getattr(self, urls[i + 1])(*args)
                 else:
-                    self.send_error(404,"Not implemented yet")
+                    self.send_error(404, "Not implemented yet")
                 break
             else:
                 pass
                 #self.loginfo("'%s' not match '%s'",self.path, urls[i])
         else:
-            self.send_error(404,"Not found")
+            self.send_error(404, "Not found")
 
     def login(self):
         mlog = do('dmap.loginresponse',
@@ -231,7 +227,7 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
         return self.send(mlog.encode())
 
     def logout(self):
-        self.send_error(204,"No Content")
+        self.send_error(204, "No Content")
 
     def server_info(self):
         name = "Listen Daap Service"
@@ -251,7 +247,7 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
                     do('dmap.supportsquery', 0),
                     do('dmap.supportsindex', 0),
                     do('dmap.supportsresolve', 0),
-                    do('dmap.databasescount', 1),                
+                    do('dmap.databasescount', 1),
                    ])
         return self.send(msrv.encode())
 
@@ -263,7 +259,7 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
                    [ do('dmap.contentcodesnumber', code),
                      do('dmap.contentcodesname', name),
                      do('dmap.contentcodestype',
-                        spydaap.daap.dmapReverseDataTypes[dtype])
+                        spydaap.daap_data.dmapReverseDataTypes[dtype])
                      ])
             children.append(d)
         mccr = do('dmap.contentcodesresponse',
@@ -296,7 +292,7 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
                  ])
         self.send(d.encode())
 
-    def item_list(self,database_id):
+    def item_list(self, database_id):
         
         def build_item(md):
             return do('dmap.listingitem',
@@ -318,10 +314,10 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
             f.write(d.encode())
         self.send(self.server.cache.get('item_list', build))
 
-    def container_list(self,database):
+    def container_list(self, database):
         container_do = []
         for i, c in enumerate(self.server.container_cache):
-            d = [ do('dmap.itemid', i + 1 ),
+            d = [ do('dmap.itemid', i + 1),
                   do('dmap.itemcount', len(c)),
                   do('dmap.containeritemid', i + 1),
                   do('dmap.itemname', c.get_name()) ]
@@ -340,9 +336,9 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
                  ])
         self.send(d.encode())
 
-    def item(self,database,item,format):
+    def item(self, database, item, format):
         fn = self.server.md_cache.get_item_by_id(item).get_original_filename()
-        self.loginfo("%s",self.headers)
+        self.loginfo("%s", self.headers)
         if self.headers.has_key('HTTP_RANGE'):
             rs = self.headers["HTTP_RANGE"]
             m = re.compile('bytes=([0-9]+)-([0-9]+)?').match(rs)
@@ -350,7 +346,9 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
             if end != None: end = int(end)
             else: end = os.stat(fn).st_size
             start = int(start)
-            self.send(f, 'audio/*', (206,"Partial Content"), 
+            f = open(fn)
+            f.seek(start)
+            self.send(f, 'audio/*', (206, "Partial Content"),
                       { "Content-Range":
                         "bytes " + str(start) + "-"
                        + str(end) + "/" + str(os.stat(fn).st_size)
@@ -364,7 +362,7 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
         self.send(container.get_daap_raw())
 
 
-    def send(self,data,type='application/x-dmap-tagged', responses = (200,), headers = {}):
+    def send(self, data, type='application/x-dmap-tagged', responses=(200,), headers={}):
         try:
             self.send_response(*responses)
             self.send_header('Content-Type', type)
@@ -375,7 +373,7 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
             #self.send_header('Content-Language', 'en_us')
             for header, value in headers.iteritems():
                 self.send_header(header, value)
-            if hasattr(data,"read"):
+            if hasattr(data, "read"):
                 data = data.read()
             if (hasattr(data, 'next')):
                 try:
@@ -395,8 +393,8 @@ class DaapRequestHandler(BaseHTTPRequestHandler,Logger):
             self.logexception("Something wrong when send data to client")
 
 class DaapServer(HTTPServer):
-    def __init__(self,server_address):
-        HTTPServer.__init__(self,server_address, DaapRequestHandler)
+    def __init__(self, server_address):
+        HTTPServer.__init__(self, server_address, DaapRequestHandler)
 
     def build_cache(self):
         cache_dir = get_xdg_cache_dir("daapcache")
@@ -422,7 +420,7 @@ class DaapdAvahi(Logger):
         self.group = None
         if dbus_imported:
             try:self.bus = dbus.SystemBus()
-            except:self.bus=None
+            except:self.bus = None
         if dbus_imported and self.bus:
             try:
                 self.server = dbus.Interface(self.bus.get_object(avahi.DBUS_NAME, avahi.DBUS_PATH_SERVER), avahi.DBUS_INTERFACE_SERVER)
@@ -431,20 +429,20 @@ class DaapdAvahi(Logger):
         else:
             print "No avahi support"
         if self.server:
-            self.server.connect_to_signal( "StateChanged", self.server_state_changed )
+            self.server.connect_to_signal("StateChanged", self.server_state_changed)
             self.server_state_changed(self.server.GetState())
 
     def add_service(self):
         if self.group is None:
-            self.group = dbus.Interface( 
-                    self.bus.get_object( avahi.DBUS_NAME, self.server.EntryGroupNew()), 
+            self.group = dbus.Interface(
+                    self.bus.get_object(avahi.DBUS_NAME, self.server.EntryGroupNew()),
                     avahi.DBUS_INTERFACE_ENTRY_GROUP)
             self.group.connect_to_signal('StateChanged', self.entry_group_state_changed)
         self.loginfo("Adding service '%s' of type '%s' ...", self.serviceName, self.serviceType)
         self.group.AddService(
-                avahi.IF_UNSPEC,    #interface
+                avahi.IF_UNSPEC, #interface
                 avahi.PROTO_UNSPEC, #protocol
-                dbus.UInt32(0),                  #flags
+                dbus.UInt32(0), #flags
                 self.serviceName, self.serviceType,
                 self.domain, self.host,
                 dbus.UInt16(self.servicePort),
@@ -478,53 +476,39 @@ class DaapdAvahi(Logger):
             self.logwarn("Error in group state changed %s", error)
 
 
-class DaapServerDialog(HelperConfigureDialog):
-    def __init__(self,parent):
-        HelperConfigureDialog.__init__(self,parent, _("DaapServer Server"))
-        self.add(self.make_lentry(_("Address"),"plugins","icecast_ip","127.0.0.1"))
-        self.add(self.make_lentry(_("Port"),"plugins","icecast_port","8000"))
-        self.add(self.make_lentry(_("Username"),"plugins","icecast_username","source"))
-        self.add(self.make_lentry(_("Password"),"plugins","icecast_password","hackme"))
-        self.add(self.make_lentry(_("Stream Name"),"plugins","icecast_name","Listen DaapServer Agent"))
-        self.add(self.make_lentry(_("Description"),"plugins","icecast_description","Listen DaapServer Agent"))
-        self.add(self.make_lentry(_("Url"),"plugins","icecast_url","http://localhost:8000/"))
-        self.add(self.make_lentry(_("Mount point"),"plugins","icecast_mount","/listen.ogg"))
-        self.show_all()
-
-
 class PortUsedException(Exception):
     pass
 
 class DaapServerPlugin(GenericPlugin):
-    PLUGIN_NAME="DaapServer Support"
-    PLUGIN_DESC="DaapServer Support plugin"
+    PLUGIN_NAME = "DaapServer Support"
+    PLUGIN_DESC = "DaapServer Support plugin"
     PLUGIN_VERSION = "0.1"
     PLUGIN_AUTHOR = "Mehdi ABAAKOUK <theli48@gmail.com>"
     PLUGIN_WEBSITE = ""
 
     def __init__(self):
-        super(DaapServerPlugin,self).__init__()
+        super(DaapServerPlugin, self).__init__()
 
-        self.autoconnect(config, "config-changed",self.__on_config_change)
+        self.autoconnect(config, "config-changed", self.__on_config_change)
         self.daapd = None
     
 
         self.port = DAAP_PORT
         while DAAP_PORT + 100 > self.port :
             try: 
-                self.daapd = DaapServer(("",self.port))
+                self.daapd = DaapServer(("", self.port))
                 break
             except :
                 self.port += 1
         if DAAP_PORT + 100 <= self.port:
-            raise PortUsedException("Port %d to %s already used"%(DAAP_PORT, self.port))
+            raise PortUsedException("Port %d to %s already used" % (DAAP_PORT, self.port))
 
         if ListenDB.isloaded():
             self.__on_db_loaded(ListenDB)
         else:
-            ListenDB.connect("loaded",self.__on_db_loaded)
+            ListenDB.connect("loaded", self.__on_db_loaded)
 
-    def __on_db_loaded(self,db):
+    def __on_db_loaded(self, db):
         self.daapd.build_cache()
         self.daapdavahi = DaapdAvahi(self.port)
         self.__id_io = gobject.io_add_watch(self.daapd.fileno(), gobject.IO_IN , self.io_callback)
@@ -533,11 +517,11 @@ class DaapServerPlugin(GenericPlugin):
         self.daapd.handle_request()
         return True
 
-    def __on_config_change(self,dispacher,section,option,value):
+    def __on_config_change(self, dispacher, section, option, value):
         if section == "plugins" and option.find("daapserver") == 0:
             pass
 
-    def destroy(self):
+    def delete_thyself(self):
         if self.daapd is not None:
             if self.__id_io:
                 gobject.source_remove(self.__id_io)
@@ -545,9 +529,5 @@ class DaapServerPlugin(GenericPlugin):
             self.daapdavahi.group.Free()
             del self.daapd
             del self.daapdavahi
-        super(DaapServerPlugin,self).destroy()
+        super(DaapServerPlugin, self).delete_thyself()
 
-    @staticmethod   
-    def on_configure(parent):
-        pass
-        #DaapServerDialog(parent)
