@@ -13,7 +13,7 @@
 #You should have received a copy of the GNU General Public License
 #along with Spydaap. If not, see <http://www.gnu.org/licenses/>.
 
-import os, sys, spydaap
+import os
 from hashlib import md5
 
 class Cache(object):
