@@ -13,15 +13,19 @@
 #You should have received a copy of the GNU General Public License
 #along with Spydaap. If not, see <http://www.gnu.org/licenses/>.
 
-import os, struct, spydaap.parser, types, spydaap, spydaap.cache, StringIO
 from hashlib import md5
-from config import config
 from spydaap.daap import do
+import os
+import struct
+import types
+import spydaap.parser
+import spydaap.cache
+import StringIO
 
 class MetadataCache(spydaap.cache.OrderedCache):
     parsers = []
     for ms in dir(spydaap.parser):
-        m = spydaap.parser.__dict__[ms]
+        m = spydaap.parser.__dict__[ms] #@UndefinedVariable
         if type(m) == types.ModuleType:
             for cs in dir(m):
                 c = m.__dict__[cs]
