@@ -13,5 +13,5 @@
 #You should have received a copy of the GNU General Public License
 #along with Spydaap. If not, see <http://www.gnu.org/licenses/>.
 
-class Parser:
+class Parser(object):
     pass
