@@ -22,9 +22,9 @@
 
 import gobject
 from xml.dom import minidom
-import urllib, re, traceback
+import urllib
 
-from widget.webtemplate import get_template
+from widget.htmlview import get_template
 
 from plugins.lyrics import LyricsPlugin
 
@@ -51,9 +51,9 @@ class LeoLyricsPlugin( LyricsPlugin):
 
         try:
             xml = minidom.parse(html_buffer)
-        except Exception, e:
-            print "W:LyricsBox:Failed fetch_lyrics_part1 xml (traceback):"
-            print traceback.format_exc()
+            html_buffer.close()
+        except Exception:
+            self.logexception("Failed fetch_lyrics_part1 xml (traceback):")
             gobject.idle_add(self.render,get_template()%(_("Server did not respond.")))
             return
         
@@ -97,9 +97,9 @@ class LeoLyricsPlugin( LyricsPlugin):
     def fetch_lyrics_leolyrics_part2(self,html_buffer,song):
         try:
             xml = minidom.parse(html_buffer)
-        except Exception, e:
-            print "W:LyricsBox:Failed fetch_lyrics_part1 xml (traceback):"
-            print traceback.format_exc()
+            html_buffer.close()
+        except Exception:
+            self.logexception("Failed fetch_lyrics_part2 xml (traceback):")
             self.render(_("Server did not respond."))
             return
         
