@@ -4,7 +4,6 @@
 ####
 
 import urllib
-import string
 import re
 
 from plugins.lyrics import LyricsPlugin
@@ -26,6 +25,8 @@ class LetrasMusBrPlugin(LyricsPlugin):
 
     def fetch_lyrics_terra(self,html_buffer,song):
         content = html_buffer.read()
+        html_buffer.close()
+
         error_msg = re.search('\<h3\>(?P<msg>.*)\<\/h3\>', content)
 
         if error_msg is not None:
