@@ -4,9 +4,6 @@
 # written by xsdnyd <xsdnyd@gmail.com>
 ###
 
-import urllib
-import string
-
 from plugins.lyrics import LyricsPlugin
 from plugins.lyrics import LyricWiki_client
 
