@@ -20,10 +20,6 @@
 #
 ###
 
-import re
-import gobject
-
-import utils
 from song import Song
 
 from vfs import urlopen
