@@ -20,23 +20,21 @@
 #
 ###
 
-import gobject
+import dbus #@UnusedImport
+import dbus.glib #@UnusedImport
 try:
-    import avahi, dbus
-    if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
-        import dbus.glib
-except ImportError: dbus_imported = False
-else: dbus_imported=True
+    import avahi
+except ImportError: avahi_imported = False
+else: avahi_imported=True
 
 
 
 class ServiceDiscover(object):
     domain = "local"
     def __init__(self): 
-        if dbus_imported:
-            try:self.bus = dbus.SystemBus()
-            except:self.bus=None    
-        if dbus_imported and self.bus:
+        self.bus = None
+        if avahi_imported:
+            self.bus = dbus.SystemBus()
             try:
                 self.server = dbus.Interface(self.bus.get_object(avahi.DBUS_NAME, avahi.DBUS_PATH_SERVER), avahi.DBUS_INTERFACE_SERVER)
             except:
@@ -49,14 +47,13 @@ class ServiceDiscover(object):
         self.id = 0
         
     def connect_service(self, stype, connect, disconnect):
-
-        if dbus_imported:
+        if avahi_imported:
             browser = dbus.Interface(self.bus.get_object(avahi.DBUS_NAME, self.server.ServiceBrowserNew(avahi.IF_UNSPEC, avahi.PROTO_UNSPEC, stype, self.domain, dbus.UInt32(0))), avahi.DBUS_INTERFACE_SERVICE_BROWSER)
             browser.connect_to_signal('ItemNew', connect)
             browser.connect_to_signal('ItemRemove', disconnect)
         
     def resolve(self,interface, protocol, name, type, domain, flags):
-        interface, protocol, name, type, domain, host, aprotocol, address, port, txt, flags = self.server.ResolveService(interface, protocol, name, type, domain, avahi.PROTO_UNSPEC, dbus.UInt32(0))
+        interface, protocol, name, type, domain, _host, _aprotocol, address, port, _txt, _flags = self.server.ResolveService(interface, protocol, name, type, domain, avahi.PROTO_UNSPEC, dbus.UInt32(0))
         return address, port,name
     
 service_discover = ServiceDiscover()
