@@ -25,7 +25,6 @@ import traceback
 import gst
 
 import gobject
-import gtk
 from time import time
 from datetime import datetime
 
@@ -58,15 +57,14 @@ from mutagen.asf import ASF
 from mutagen.apev2 import APEv2File
 from mutagen.flac import FLAC
 from mutagen.id3 import ID3FileType
-from mutagen.mp3 import MP3
 from mutagen.oggflac import OggFLAC
 from mutagen.oggspeex import OggSpeex
 from mutagen.oggtheora import OggTheora
 from mutagen.oggvorbis import OggVorbis
 from mutagen.trueaudio import TrueAudio
 from mutagen.wavpack import WavPack
-try: from mutagen.mp4 import MP4
-except: from mutagen.m4a import M4A as MP4
+try: from mutagen.mp4 import MP4 #@UnusedImport
+except: from mutagen.m4a import M4A as MP4 #@Reimport
 from mutagen.musepack import Musepack
 from mutagen.monkeysaudio import MonkeysAudio
 from mutagen.optimfrog import OptimFROG
@@ -160,12 +158,13 @@ KEY_TYPES= {
     }
 
 class Song(dict, Logger):
-    def __init__(self, otherdict = None):
-        dict.__init__(self)
+    def sanitarize_init_from_dict(self, otherdict = None):
         if otherdict:
             for key in USED_KEYS:
-                default = key[0] == 0 and 0 or None
-                self[key] = otherdict.get(key,None)
+                default = (key.startswith("#")) and 0 or None
+                self[key] = otherdict.get(key,default)
+        if "#added" not in self:
+            self["#added"] = time()
 
     def get_dict(self):
         odict = {}
@@ -279,10 +278,6 @@ class Song(dict, Logger):
         if isinstance(value,str): value = unicode(value)
         return value
 
-    def sanitarize(self):
-        if "#added" not in self:
-            self["#added"] = time()
-
     def __setitem__(self, key, value):
         if key == "#track":
             if value is not None and not isinstance(value,int) and value.rfind("/")!=-1 and value.strip()!="":
@@ -462,8 +457,6 @@ class Song(dict, Logger):
             state_ret = pipeline.set_state(gst.STATE_NULL)
             if state_ret != gst.STATE_CHANGE_SUCCESS:
                 print "Failed change to null"
-            is_finalize = True
-            #print "finalize"
                 
             
         def message(bus,message,pipeline):
@@ -501,9 +494,8 @@ class Song(dict, Logger):
             
             state_ret = pipeline.set_state(gst.STATE_PAUSED);
             timeout = 10
-            state = None
             while state_ret == gst.STATE_CHANGE_ASYNC and not is_finalize and timeout > 0:
-                state_ret,state,pending_state = pipeline.get_state(1 * gst.SECOND);
+                state_ret, _state, _pending_state = pipeline.get_state(1 * gst.SECOND);
                 timeout -= 1
                 
             if state_ret != gst.STATE_CHANGE_SUCCESS:
