@@ -23,9 +23,9 @@
 import gobject
 import gtk
 import threading
-import utils,stock
+import stock
 
-from source import Source,SourceItem
+from source import Source, SourceItem
 from widget.song_view import SortableSongView
 from widget.song_menu import SongMenu , SongMenuManager
 from widget.misc import ScrolledWindow
@@ -34,17 +34,16 @@ from library import ListenDB
 from helper import Dispatcher
 from hal import hal
 try: 
-    import musicbrainz2
     import musicbrainz2.disc as disc
     import musicbrainz2.webservice as ws
 except:
     print "No Audio cd support (musicbrainz2 missing)"
 
 class MusicBrainzAudioCD(object):
-    def __init__(self,device):
+    def __init__(self, device):
         self.device = device
         try: self.cd = disc.readDisc(device)    
-        except: self.disc_id=None
+        except: self.disc_id = None
         else: self.disc_id = self.cd.getId()
         
     def get_mb_release_id(self):
@@ -58,10 +57,10 @@ class MusicBrainzAudioCD(object):
                 return results[0].release.getId()               
         return None
                 
-    def get_mb_release(self,id):
+    def get_mb_release(self, id):
         q = ws.Query()    
         include = ws.ReleaseIncludes(artist=True, tracks=True)
-        try : res = q.getReleaseById(id,include)
+        try : res = q.getReleaseById(id, include)
         except: return None
         else: return res
         
@@ -77,17 +76,17 @@ class MusicBrainzAudioCD(object):
             print "W:MusicBrainzAudioCD:No release found"
             cd_tracks = self.cd.getTracks()
             tracks_tags = []
-            for i in range(0,len(cd_tracks)):
+            for i in range(0, len(cd_tracks)):
                 t = cd_tracks[i]
                 # an audio CD sector size = 2352 
                 # and audio CD encoded at 44.1KHz, Stereo, with 16-bit/sample 
                 tags = {
-                    "title" : _("Track")+" %d"%(i+1),
+                    "title" : _("Track") + " %d" % (i + 1),
                     "album" : _("Unknown album"),
                     "artist" : _("Unknown artist"),
-                    "#track" : (i+1),
-                    "uri" : "cdda://%d#%s"%(i+1,self.device),
-                    "#duration" : (t[1]*2352)/(2*2*44100)*1000
+                    "#track" : (i + 1),
+                    "uri" : "cdda://%d#%s" % (i + 1, self.device),
+                    "#duration" : (t[1] * 2352) / (2 * 2 * 44100) * 1000
                     }
                 tracks_tags.append(tags)
             return tracks_tags
@@ -103,7 +102,7 @@ class MusicBrainzAudioCD(object):
         
         tracks_tags = []
         
-        for i in range(0,len(tracks)):
+        for i in range(0, len(tracks)):
             t = tracks[i]
             cd_t = cd_tracks[i]
             tags = {
@@ -111,9 +110,9 @@ class MusicBrainzAudioCD(object):
                 "album" : album_name,
                 "#date" : date_album,
                 "artist" : artist_name,
-                "#track" : (i+1),
-                "uri" : "cdda://%d#%s"%(i+1,self.device),
-                "#duration" : (cd_t[1]*2352)/(2*2*44100)*1000
+                "#track" : (i + 1),
+                "uri" : "cdda://%d#%s" % (i + 1, self.device),
+                "#duration" : (cd_t[1] * 2352) / (2 * 2 * 44100) * 1000
                 }
             tracks_tags.append(tags)
         return tracks_tags
@@ -133,56 +132,57 @@ class AudioCDSource(Source):
 
         self.play_device = None
         self.audiocd_items = {}
-        ListenDB.register_type("audiocdtrack",["lyrics","wikipedia","lastfminfo","audioscrobbler","current"])
-        for item_menu in [ "play", "enqueue" ,"lastfm","wikipedia_artist","wikipedia_album","lyrics"]:
-            SongMenuManager.allow_item_for_type(item_menu,"audiocdtrack")
+        ListenDB.register_type("audiocdtrack", ["lyrics", "wikipedia", "lastfminfo", "audioscrobbler", "current"])
+        for item_menu in [ "play", "enqueue" , "lastfm", "wikipedia_artist", "wikipedia_album", "lyrics"]:
+            SongMenuManager.allow_item_for_type(item_menu, "audiocdtrack")
 
         try: 
-            import musicbrainz2
-        except: pass
+            import musicbrainz2 #@UnusedImport
+        except: 
+            pass
         else: 
-            self.autoconnect(hal,"volume-mounted",self.mount)
-            self.autoconnect(hal,"volume-umounted",self.umount)
-        self.autoconnect(Dispatcher,"play-device",self.on_play_device)
+            self.autoconnect(hal, "volume-mounted", self.mount)
+            self.autoconnect(hal, "volume-umounted", self.umount)
+        self.autoconnect(Dispatcher, "play-device", self.on_play_device)
         for udi in hal.get_mounted_devices_udi():
-            gobject.idle_add(self.mount,hal, udi)
+            gobject.idle_add(self.mount, hal, udi)
         
     
-    def on_play_device(self,helper,path):
-        for udi,(item,device) in self.audiocd_items.iteritems():
-            if path==device:
-                songs = [ s for s in ListenDB.get_songs("audiocdtrack") if s.get("uri").endswith("#"+device) ]
+    def on_play_device(self, helper, path):
+        for _udi, (_item, device) in self.audiocd_items.iteritems():
+            if path == device:
+                songs = [ s for s in ListenDB.get_songs("audiocdtrack") if s.get("uri").endswith("#" + device) ]
                 Dispatcher.cur_playlist_play(songs)
         self.play_device = path
         
-    def check(self,udi):
-        if hal.get_property(udi,"volume.disc.has_audio"):
+    def check(self, udi):
+        if hal.get_property(udi, "volume.disc.has_audio"):
             return True
         return False
         
-    def mount(self,hal,udi):
+    def mount(self, hal, udi):
         if not self.check(udi): return
         device_path = hal.get_device_path(udi)
         
         if device_path:
-            t = threading.Thread(target=self.post_mount_thread,args=(device_path,udi))
+            t = threading.Thread(target=self.post_mount_thread, args=(device_path, udi))
             t.setDaemon(True)
             t.start()
                 
-    def post_mount_thread(self,device,udi):
-        gobject.idle_add(self.post_mount_cb,MusicBrainzAudioCD(device).get_tracks(),device,udi)
+    def post_mount_thread(self, device, udi):
+        gobject.idle_add(self.post_mount_cb, MusicBrainzAudioCD(device).get_tracks(), device, udi)
         
-    def post_mount_cb(self,tracks_tags,device,udi):
-        if len(tracks_tags) >0 :
-            songs = [ ListenDB.get_or_create_song(track,"audiocdtrack") for track in tracks_tags]
-            item = AudioCDSourceItem(device,songs)
+    def post_mount_cb(self, tracks_tags, device, udi):
+        if len(tracks_tags) > 0 :
+            songs = [ ListenDB.get_or_create_song(track, "audiocdtrack") for track in tracks_tags]
+            item = AudioCDSourceItem(device, songs)
                
-            self.audiocd_items[udi] = (item,device)
-            if self.play_device==device:
+            self.audiocd_items[udi] = (item, device)
+            if self.play_device == device:
                 Dispatcher.cur_playlist_play(songs)
             self.build_source_items()
 
-    def umount(self,hal,udi):
+    def umount(self, hal, udi):
         if udi and self.audiocd_items.has_key(udi):
             ListenDB.remove(self.audiocd_items[udi][1].songs)
             del self.audiocd_items[udi]
@@ -190,7 +190,7 @@ class AudioCDSource(Source):
         
     def build_source_items(self):
         self.items = []
-        for udi,(item,device) in self.audiocd_items.iteritems():
+        for _udi, (item, _device) in self.audiocd_items.iteritems():
             self.items.append(item)
         Dispatcher.update_source()
         
@@ -202,7 +202,7 @@ class AudioCDSourceItem(SourceItem):
     stock = stock.WIKI_CD
     config_code = "audiocd"
 
-    def __init__(self,device,songs):
+    def __init__(self, device, songs):
         self.songs = songs
         self.device = device
         view = AudioCDSongView()
@@ -210,7 +210,7 @@ class AudioCDSourceItem(SourceItem):
         self.widget = ScrolledWindow(view)
         self.label = songs[0].get_str("album")
     
-    def on_drag_data_get(self,context, selection, info):
+    def on_drag_data_get(self, context, selection, info):
         list_uri = [ s.get("uri") for s in self.songs ]
         #ListenDB.get_songs("audiocdtrack") if s.get("uri").endswith("#"+self.device)
         selection.set("text/listen-songs", 8, "\n".join(list_uri))
@@ -220,28 +220,28 @@ class AudioCDSourceItem(SourceItem):
     def on_activated(self):
         self.play_playlist()
         
-    def play_playlist(self,w=None):
-        if len(self.songs)>0:
+    def play_playlist(self, w=None):
+        if len(self.songs) > 0:
             Dispatcher.cur_playlist_play(self.songs)
                
-    def enqueue_playlist(self,w):
-        if len(self.songs)>0:
+    def enqueue_playlist(self, w):
+        if len(self.songs) > 0:
             Dispatcher.cur_playlist_enqueue(self.songs)  
             
     def get_menu(self):
         menu = gtk.Menu()
         item = gtk.ImageMenuItem(stock.PLAY)
-        item.connect("activate",self.play_playlist)
+        item.connect("activate", self.play_playlist)
         menu.append(item)
         item = gtk.ImageMenuItem(stock.ENQUEUE)
-        item.connect("activate",self.enqueue_playlist)
+        item.connect("activate", self.enqueue_playlist)
         menu.append(item)
         menu.show_all()
         return menu
         
 class AudioCDSongView(SortableSongView):
     def __init__(self):
-        super(AudioCDSongView,self).__init__("audiocd")
+        super(AudioCDSongView, self).__init__("audiocd")
         self.menu = SongMenu()
         self.set_menu(self.menu)
 
