@@ -20,11 +20,7 @@
 #
 ###
 
-import gobject
-import gtk
 import stock
-import utils
-from config import config
 
 from widget.lastfm_station_view import LastfmWidget
 from source import Source,SourceItem
@@ -41,6 +37,7 @@ class LastFmRadioSource(Source):
 
     display_index = 55
     def __init__(self):
+        Source.__init__(self)
         self.items = [ LastFmItem() ]   
 
     def save(self):
