@@ -23,29 +23,24 @@
 import os
 import gobject
 import gtk
-import threading
 from time import time
 
 import traceback
 
 import stock
-import utils
 from config import config
 import vfs
 from xdg_support import get_xdg_music_dir
 
 from source import Source,SourceItem
-from widget.song_view import SortableSongView
-from widget.song_menu import SongMenu
 from widget.browser import SimpleBrowser
 from widget.jobs_manager import Job
 from cover_manager import CoverManager
 from widget.dialog import WinDir, WinFile
 from widget.smart_playlist import SmartPlaylistWindow
 
-from helper import Dispatcher
 
-from library import ListenDB, ListenDBQuery
+from library import ListenDB
 
 from song import file_is_supported
 
@@ -119,12 +114,12 @@ class LocalSource(Source):
     display_index = 50
 
     def __init__(self):
+        Source.__init__(self)
         self.items = [LocalLibrarySourceItem()]
         if ListenDB.isloaded():
             self.__post_load()
         else:
             ListenDB.connect("loaded",self.__post_load)
-        Source.__init__(self)
 
     def __post_load(self, *args):
         self.logdebug("post load launch")
@@ -160,14 +155,6 @@ class CoverDownloadJob(Job):
             progress = float(i)/float(total)
             yield _("Download cover ")+" %d/%d"%(i,total),progress,False
         del album_songs
-
-        
-    def told_way(self):
-        songs = [s for s in album_songs.values() if not CoverManager.has_cover(s) ]
-        total = len(songs)
-        self.loginfo("%s cover to download",total)
-        for i in range(0,total):
-            CoverManager.get_cover(songs[i], True)
         
 
 class ImportFolderJob(Job):
@@ -218,15 +205,13 @@ class ImportFolderJob(Job):
 
         i = 0
         total = len(added)
-        finish = []
         added = set(added)
         for uri in added:
             i += 1
             tags = {"uri":uri}
             try: ListenDB.get_or_create_song(tags,"local",read_from_file=True)
             except:
-                import traceback
-                traceback.print_exc()
+                self.logerror("Failed load %s", uri)
             yield _("Reading file")+" %d/%d..."%(i,total),float(i)/float(total),False
         
         end = time()
