@@ -21,24 +21,17 @@
 ###
 
 
-import gobject
 import gtk
 
 import stock
-import utils
-from config import config
 
-from source import Source,SourceItem, PlaylistSource, PlaylistSourceItem
+from source import PlaylistSource, PlaylistSourceItem
 from widget.song_view import PlaylistSongView,SortableSongView
-from widget.song_model import SongModel
-from widget.song_menu import SongMenu
 from widget.browser import AutoPlaylistBrowser
-from widget.misc import ScrolledWindow
 from widget.smart_playlist import SmartPlaylistWindow
 
-from helper import Dispatcher
 
-from library import ListenDB, ListenDBQuery
+from library import ListenDB
 
 class LocalAutoPlaylistBrowser(AutoPlaylistBrowser):
     _type = "local"
