@@ -20,7 +20,6 @@
 #
 ###
 
-import os
 
 import gobject
 import gtk
@@ -36,47 +35,13 @@ from helper import Dispatcher, SignalCollector
 from library import ListenDB
 from player import Player
 from web_threading import WebFetchThread
-from widget.webtemplate import get_template
 
 from source import Source,SourceItem
 from widget.song_menu import SongMenuManager
 
-from logger import newLogger
-
-mylogger = newLogger("wikipedia")
+from widget.htmlview import HtmlView, get_template
 
 WIKIPEDIA_HISTORY_LEN = 20
-
-try:
-    import webkit
-except ImportError:
-    webkit = None
-try: 
-    from widget.mozembed_wrap import MozClient
-except ImportError:
-    MozClient = None
-except: 
-    mylogger.exception("Failed import mozembed wrapper")
-    MozClient = None
-
-backend = os.environ.get("LISTEN_BROWSER",None)
-if webkit and backend == "webkit":
-    USEWEBKIT = True
-elif MozClient and backend == "mozilla":
-    USEWEBKIT = False
-else:
-    if not webkit and not MozClient:
-        raise ImportError("missing python-webkit (recommended) or python-mozembed")
-    elif backend:
-        raise ImportError('LISTEN_BROWSER support only "webkit" or "mozilla"')
-    # Fallback
-    elif webkit:
-        USEWEBKIT = True
-    elif MozClient:
-        USEWEBKIT = False
-
-mylogger.info("wikipedia use %s has browser backend",(USEWEBKIT and "webkit" or "mozilla") )
-
 WIKI_HOTE = "%s.wikipedia.org"
 WIKI_URL = WIKI_HOTE+"/wiki/"
 WIKI_URL = WIKI_HOTE+"/wiki/Special:Search/"
@@ -87,13 +52,10 @@ class WikiBox(gtk.VBox):
 
         self.last_action = "artist"
         self.song = None
+        
 
-        if USEWEBKIT:
-            self.embed = webkit.WebView()
-            SignalCollector.connect("wikipedia",self.embed,"navigation-requested", self.webkit_link_uri_cb)
-        else:
-            self.embed = MozClient()
-            SignalCollector.connect("wikipedia",self.embed,"open-uri",self.moz_link_uri_cb)
+        self.embed = HtmlView()
+        self.embed.set_open_uri_callback(self.link_uri_cb)
 
         self.btn_forward = self.make_btn(gtk.STOCK_GO_FORWARD,"forward")
         self.btn_forward.set_tooltip_text(_("Forward"))
@@ -117,11 +79,9 @@ class WikiBox(gtk.VBox):
         SignalCollector.connect("wikipedia",self.btn_browser,"clicked",self.open_in_browser)
         self.btn_browser.set_tooltip_text(_("See in web browser"))
 
-        model = gtk.ListStore(gobject.TYPE_STRING)
-
         self.dropdown_lang = gtk.combo_box_new_text()
 
-        langs = config.get("wikipedia","lang").split("<###>")
+        langs = self.get_config_langs()
         active = 0
         self.lang = "en"
         for lang in langs:
@@ -132,6 +92,9 @@ class WikiBox(gtk.VBox):
 
         if langs: 
             self.dropdown_lang.set_active(active)
+        else:
+            self.dropdown_lang.set_active(0)
+
         SignalCollector.connect("wikipedia",self.dropdown_lang,"changed",self.on_change_lang)
         self.dropdown_lang.set_tooltip_text(_("Change wikipedia language"))
 
@@ -147,7 +110,6 @@ class WikiBox(gtk.VBox):
         self.label3 = gtk.Label(label[2].strip())
 
         hbox = gtk.HBox(False,6)
-        hbox2 = gtk.HBox(False,6)
 
         hbox.pack_start(self.btn_browser,False,False)
         hbox.pack_start(self.btn_back,False,False)
@@ -160,12 +122,9 @@ class WikiBox(gtk.VBox):
 
         hbox.pack_end(self.auto_update,False,False)
 
-        #self.pack_start(hbox2,False,False)
         self.pack_start(hbox,False,False)
 
-        f = gtk.Frame()
-        f.add(self.embed)
-        self.pack_start(f)
+        self.pack_start(self.embed)
         self.embed.show_all()
         self.site_cache={}
         
@@ -181,25 +140,33 @@ class WikiBox(gtk.VBox):
         self.download_thread = WebFetchThread(1024,self.fail_fetch)
         #self.download_thread.dbg = True
     
+    def get_config_langs(self):
+        """return a array of configured wikipedia language"""
+        values = config.get("wikipedia","lang").split(";")
+        return values
+
     def update_lang(self,helper,section,key,value):
         if section != "wikipedia" or key != "lang": return
         
-        for i in range(0,len(self.dropdown_lang.get_model())):
+        for __ in range(0,len(self.dropdown_lang.get_model())):
             self.dropdown_lang.remove_text(0)
-
-        langs = config.get("wikipedia","lang").split("<###>")
+        active = 0
+        langs = self.get_config_langs()
         for lang in langs:
             if lang == config.get("setting","wikipedia"):
                 active = langs.index(lang)
                 self.lang=lang
             self.dropdown_lang.append_text("%s.wikipedia.org"%lang)
-        self.dropdown_lang.set_active(active)
+        if langs:
+            self.dropdown_lang.set_active(active)
+        else:
+            self.dropdown_lang.set_active(0)
 
     def fail_fetch(self):
         HTML = get_template()%("<h3>"+_("Failed to retreive data")+"</h3>")
         self.render_data(HTML)
         
-    def moz_link_uri_cb(self,w,uri):
+    def link_uri_cb(self, uri):
         if uri.find("wikipedia.org")!=-1 or uri.find("wikimedia.org")!=-1:
             if self.current_url:
                 self.go_back_url.append(self.current_url)
@@ -209,34 +176,19 @@ class WikiBox(gtk.VBox):
             utils.website(uri);
         return True
 
-    def webkit_link_uri_cb(self, view, frame, networkRequest):
-        uri = networkRequest.get_uri()
-        if uri == self.current_url: return False
-        if uri.find("wikipedia.org")!=-1 or uri.find("wikimedia.org")!=-1:
-            if self.current_url:
-                self.go_back_url.append(self.current_url)
-            self.go_forward_url = []
-            self.download_uri(uri)
-        else:
-            utils.website(uri);
-        return True
-        
     def download_uri(self,uri):
         self.current_url = uri
         self.download_thread.fetch_url(uri,self.render_data,True)
         
-        
-    def render_data(self,html,prepare_data=False):
+    def render_data(self, html,prepare_data=False):
         if not isinstance(html,str) and not isinstance(html,unicode):
-            html = html.read()
+            f = html
+            html = f.read()
+            f.close()
         if prepare_data:
             html = self.prepare_html(html)
-        if USEWEBKIT:
-            self.embed.load_html_string(html, self.current_url or "" )
-        else:
-            self.embed.set_data(self.current_url,html)
+        self.embed.load_html_string(html, self.current_url or "" )
         gobject.idle_add(self.update_btn_status)
-            
 
     def open_in_browser(self,btn=None):
         if self.current_url:
@@ -248,9 +200,11 @@ class WikiBox(gtk.VBox):
         self.fetch_information(None,action_map[i])
 
     def on_change_lang(self,widget):
-        self.lang = self.dropdown_lang.get_active_text().replace(".wikipedia.org","")
-        config.set("setting","wikipedia",self.lang)
-        self.fetch_information(None,self.last_action)
+        text = self.dropdown_lang.get_active_text()
+        if text:
+            self.lang = text.replace(".wikipedia.org","")
+            config.set("setting","wikipedia",self.lang)
+            self.fetch_information(None,self.last_action)
         
     def force_select(self,action,song):
         if action: self.set_action(action)
@@ -267,20 +221,21 @@ class WikiBox(gtk.VBox):
         #SignalCollector.connect("wikipedia",self.dropdown_info,"changed",self.on_change_info)
 
 
-    def make_btn(self,stocks,action,label=None,btn=None):
-        if label==None:
-           btn = gtk.Button()
-           image = gtk.image_new_from_stock(stocks, gtk.ICON_SIZE_BUTTON)
-           btn.add(image)
+    def make_btn(self, stocks, action, label=None, btn=None):
+
+        if label == None:
+            btn = gtk.Button()
+            image = gtk.image_new_from_stock(stocks, gtk.ICON_SIZE_BUTTON)
+            btn.add(image)
         else:
-           btn = gtk.RadioButton(group=btn)
-           image = gtk.image_new_from_stock(stocks, gtk.ICON_SIZE_BUTTON)
-           label = gtk.Label(label)
-           label.set_alignment(0,0.5)
-           box = gtk.HBox(False,6)
-           box.pack_start(image,False,False)
-           box.pack_start(label,True,True)
-           btn.add(box)
+            btn = gtk.RadioButton(group=btn)
+            image = gtk.image_new_from_stock(stocks, gtk.ICON_SIZE_BUTTON)
+            label = gtk.Label(label)
+            label.set_alignment(0, 0.5)
+            box = gtk.HBox(False, 6)
+            box.pack_start(image, False, False)
+            box.pack_start(label, True, True)
+            btn.add(box)
 
         SignalCollector.connect("wikipedia",btn,"clicked",self.fetch_information,action)
         return btn
@@ -390,6 +345,7 @@ class WikipediaSource(Source):
     signal_collector_id = "wikipedia"
 
     def __init__(self):
+        Source.__init__(self)
         item = WikipediaItem()
         self.items = [ item ]
 
@@ -408,10 +364,8 @@ class WikipediaSource(Source):
             SongMenuManager.allow_item_for_type("wikipedia_artist",type)
             SongMenuManager.allow_item_for_type("wikipedia_album",type)
 
-        Source.__init__(self)
-
-    def destroy(self):
+    def delete_thyself(self):
         SongMenuManager.unregister_item("wikipedia_artist")
         SongMenuManager.unregister_item("wikipedia_album")
-        Source.destroy(self)
+        Source.delete_thyself(self)
 
