@@ -28,8 +28,6 @@ import gobject
 
 from logger import Logger
 
-from urllib import urlencode
-
 #Configuration
 mp3_quality = {
     "cbr": (64, 96, 128, 192, 256),
@@ -37,11 +35,11 @@ mp3_quality = {
     "vbr": (9, 7, 5, 3, 1),
 }
 mp3_mode = {
-    "cbr" : (0,"bitrate"),
-    "abr" : (3,"vbr-mean-bitrate"),
-    "vbr" : (4,"vbr-quality")
+    "cbr" : (0, "bitrate"),
+    "abr" : (3, "vbr-mean-bitrate"),
+    "vbr" : (4, "vbr-quality")
 }
-ogg_quality =  (0,0.2,0.4,0.6,0.8)
+ogg_quality = (0, 0.2, 0.4, 0.6, 0.8)
 
 FORMAT_PERCENT_SCALE = 10000
 CLOCK_SPEED = 10
@@ -58,21 +56,21 @@ class TrancoderError(Exception):
 class Transcoder(Logger):
     pipe = "gnomevfssrc location=\"%s\" ! decodebin name=decoder ! audioconvert ! %s name=encoder ! gnomevfssink location=\"%s\""
     is_eos = False
-    def __init__(self,input,output,format="mp3",quality=3,mode="cbr"):
+    def __init__(self, input, output, format="mp3", quality=3, mode="cbr"):
         
-        if format=="mp3":
-            encoder = "lame quality=2 xingheader=0 vbr=%d %s=%d"%(mp3_mode[mode][0],mp3_mode[mode][1],mp3_quality[mode][quality])
-        elif format=="ogg":
-            encoder = "vorbisenc quality=%d"%ogg_quality[quality]
-        elif format=="flac":    
+        if format == "mp3":
+            encoder = "lame quality=2 xingheader=0 vbr=%d %s=%d" % (mp3_mode[mode][0], mp3_mode[mode][1], mp3_quality[mode][quality])
+        elif format == "ogg":
+            encoder = "vorbisenc quality=%d" % ogg_quality[quality]
+        elif format == "flac":    
             encoder = "flacenc"
         else:
             raise TrancoderError("Format unknown")
 
-        pipe = self.pipe%(input,encoder,output)
-        self.loginfo("build pipeline \"%s\"",pipe)
+        pipe = self.pipe % (input, encoder, output)
+        self.loginfo("build pipeline \"%s\"", pipe)
         try: self.pipeline = gst.parse_launch (pipe);
-        except gobject.GError, e : 
+        except gobject.GError: 
             self.logexception("failed to build the pipeline")
             raise TrancoderError
         
@@ -80,16 +78,15 @@ class Transcoder(Logger):
         self.encoder = self.pipeline.get_by_name("encoder")
         
         decoder = self.pipeline.get_by_name("decoder")
-        decoder.connect("unknown-type",self.unknown_type)
+        decoder.connect("unknown-type", self.unknown_type)
         bus = self.pipeline.get_bus()
         bus.connect('message', self.message)
         bus.add_signal_watch()
         
         state_ret = self.pipeline.set_state(gst.STATE_PLAYING);
         timeout = 10
-        state = None
         while state_ret == gst.STATE_CHANGE_ASYNC and not self.is_eos and timeout > 0:
-            state_ret,state,pending_state = self.pipeline.get_state(1 * gst.SECOND);
+            state_ret, __state, __pending_state = self.pipeline.get_state(1 * gst.SECOND);
             timeout -= 1
             
         if state_ret != gst.STATE_CHANGE_SUCCESS:
@@ -102,7 +99,7 @@ class Transcoder(Logger):
         return self.is_eos
     
     def get_ratio(self):
-        ratio = float(self.get_position())/float(self.duration)*float(100)
+        ratio = float(self.get_position()) / float(self.duration) * float(100)
         return  ratio
     
     def get_position(self):
@@ -127,7 +124,7 @@ class Transcoder(Logger):
         else:
             return 0
         
-    def unknown_type(self,*param):
+    def unknown_type(self, *param):
         self.logwarn("input file type unknown")
         raise TrancoderError
     
@@ -141,10 +138,10 @@ class Transcoder(Logger):
         self.is_eos = True
             
     def get_state(self):
-        state_ret,state,pending_state = self.pipeline.get_state();
+        __state_ret, state, __pending_state = self.pipeline.get_state();
         return state
     
-    def message(self,bus,message):
+    def message(self, bus, message):
         if message.type == gst.MESSAGE_EOS:
             self.eos()
 
@@ -166,7 +163,8 @@ class Transcoder(Logger):
 
         elif message.type == gst.MESSAGE_ERROR:
             err, debug = message.parse_error()
-            self.logerror("failed decode (error: %s,%s)",err,debug)
+            self.logerror("failed decode (error: %s,%s)", err, debug)
             self.eos()
             #raise GstTagReadingError
               
+
