@@ -21,32 +21,33 @@
 ###
 
 import os
-import sys
 import gobject
 import threading
 from pyinotify import ThreadedNotifier, WatchManager, ProcessEvent, EventsCodes
 from xdg_support import get_xdg_music_dir
 
+
+
 if hasattr(EventsCodes,"IN_MOVE_SELF"):
     # pynotify <= 0.8
-    IN_MOVED_FROM = EventsCodes.IN_MOVED_FROM
-    IN_CREATE = EventsCodes.IN_CREATE
-    IN_MOVED_TO = EventsCodes.IN_MOVED_TO
-    IN_DELETE = EventsCodes.IN_DELETE
-    IN_ISDIR = EventsCodes.IN_ISDIR
-    IN_DELETE_SELF = EventsCodes.IN_DELETE_SELF
-    IN_CLOSE_WRITE = EventsCodes.IN_CLOSE_WRITE
-    IN_MOVE_SELF = EventsCodes.IN_MOVE_SELF
+    IN_MOVED_FROM = EventsCodes.IN_MOVED_FROM #@UndefinedVariable
+    IN_CREATE = EventsCodes.IN_CREATE #@UndefinedVariable
+    IN_MOVED_TO = EventsCodes.IN_MOVED_TO #@UndefinedVariable
+    IN_DELETE = EventsCodes.IN_DELETE #@UndefinedVariable
+    IN_ISDIR = EventsCodes.IN_ISDIR #@UndefinedVariable
+    IN_DELETE_SELF = EventsCodes.IN_DELETE_SELF #@UndefinedVariable
+    IN_CLOSE_WRITE = EventsCodes.IN_CLOSE_WRITE #@UndefinedVariable
+    IN_MOVE_SELF = EventsCodes.IN_MOVE_SELF #@UndefinedVariable
 else:
     import pyinotify
-    IN_MOVED_FROM = pyinotify.IN_MOVED_FROM
-    IN_CREATE = pyinotify.IN_CREATE
-    IN_MOVED_TO = pyinotify.IN_MOVED_TO
-    IN_DELETE = pyinotify.IN_DELETE
-    IN_ISDIR = pyinotify.IN_ISDIR
-    IN_DELETE_SELF = pyinotify.IN_DELETE_SELF
-    IN_CLOSE_WRITE = pyinotify.IN_CLOSE_WRITE
-    IN_MOVE_SELF = pyinotify.IN_MOVE_SELF
+    IN_MOVED_FROM = pyinotify.IN_MOVED_FROM #@UndefinedVariable
+    IN_CREATE = pyinotify.IN_CREATE #@UndefinedVariable
+    IN_MOVED_TO = pyinotify.IN_MOVED_TO #@UndefinedVariable
+    IN_DELETE = pyinotify.IN_DELETE #@UndefinedVariable
+    IN_ISDIR = pyinotify.IN_ISDIR #@UndefinedVariable
+    IN_DELETE_SELF = pyinotify.IN_DELETE_SELF #@UndefinedVariable
+    IN_CLOSE_WRITE = pyinotify.IN_CLOSE_WRITE #@UndefinedVariable
+    IN_MOVE_SELF = pyinotify.IN_MOVE_SELF #@UndefinedVariable
 
 from logger import Logger
 import vfs
