@@ -22,7 +22,6 @@
 
 
 import os
-import re
 import shutil
 import gtk
 import gobject
@@ -31,13 +30,14 @@ import time
 
 import threading
 
-import socket 
-socket.setdefaulttimeout(5)
+DEFAULT_TIMEOUT=10
 
-from urllib import pathname2url, url2pathname, quote_plus, unquote_plus, quote, unquote
+import socket 
+socket.setdefaulttimeout(DEFAULT_TIMEOUT)
+
+from urllib import pathname2url, quote, unquote
 from urllib2 import build_opener, ProxyHandler, Request
-from xml.dom.minidom import parseString
-from urlparse import urlparse, urlunparse
+from urlparse import urlparse
 
 from proxy import discover_http_proxy
 from logger import newLogger
@@ -47,31 +47,31 @@ from logger import newLogger
 logger = newLogger("vfs.vfsutils")
 
 
-def urlopen(url):
+def urlopen(url, timeout=DEFAULT_TIMEOUT):
     hproxy = ProxyHandler(discover_http_proxy())
     opener = build_opener(hproxy)
     req = Request(url)
-    req.add_header("Accept","*/*")
-    return opener.open(req)
+    req.add_header("Accept", "*/*")
+    return opener.open(req, timeout=timeout)
 
 def get_scheme(uri):
-    if uri.rfind("://")==-1: return ""
+    if uri.rfind("://") == -1: return ""
     scheme = uri[:uri.index("://")]
     return scheme.lower()
 
-def get_ext(uri, complete = True):
-    if uri.rfind(".")==-1:
+def get_ext(uri, complete=True):
+    if uri.rfind(".") == -1:
         return ""
     if get_scheme(uri) in [ "http", "https" ]:
-        if uri.rfind("#")!=-1:
+        if uri.rfind("#") != -1:
             uri = uri[:uri.rindex("#")]
-        if uri.rfind("?")!=-1:
+        if uri.rfind("?") != -1:
             uri = uri[:uri.rindex("?")]
     if complete:
         return uri[uri.rindex("."):].lower()
     else:
         if uri[-1:] == ".": return ""
-        return uri[uri.rindex(".")+1:].lower()
+        return uri[uri.rindex(".") + 1:].lower()
 
 def islocaldir(uri):
     if not get_scheme(uri) == "file": return False
@@ -84,9 +84,9 @@ mimetypes.init()
 def get_mime_type(uri):
     # Minimum mime_type support for webradio
     if get_scheme(uri) in [ "http", "https" ]:
-        if uri.rfind("#")!=-1:
+        if uri.rfind("#") != -1:
             uri = uri[:uri.rindex("#")]
-        if uri.rfind("?")!=-1:
+        if uri.rfind("?") != -1:
             uri = uri[:uri.rindex("?")]
     mimetype = mimetypes.guess_type(uri)[0]
     return mimetype
@@ -109,7 +109,7 @@ def realuri(uri):
 def read_entire_file(uri):
     data = ""
     if get_scheme(uri) == "file":
-        f = file(get_path_from_uri(uri),"r")
+        f = file(get_path_from_uri(uri), "r")
         data = f.read()
         f.close()
     else:
@@ -118,7 +118,7 @@ def read_entire_file(uri):
             data = f.read()
             f.close()
         except :
-            logger.exception("failed read %s",uri)
+            logger.logexception("failed read %s", uri)
             data = ""
     return data
 
@@ -126,7 +126,7 @@ def make_uri_from_shell_arg(arg):
     scheme = get_scheme(arg)
     if scheme: return arg
     else: 
-        return "file://"+pathname2url(os.path.abspath(os.path.expanduser(arg)))
+        return "file://" + pathname2url(os.path.abspath(os.path.expanduser(arg)))
 
 def get_name(value):
     return get_path_from_uri(value).split("/")[-1]
@@ -140,7 +140,7 @@ def get_path_from_uri(value):
 def get_uri_from_path(value):
     if get_scheme(value): return value
     else: 
-        return "file://"+quote(value)
+        return "file://" + quote(value)
 
 def unescape_string_for_display(value):
     return unquote(value)
@@ -165,9 +165,9 @@ def exists(uri):
         path = get_path_from_uri(uri)
         return os.path.exists(path)
 
-def makedirs(uri,mode=0755):
-    if uri.find("://")!=-1:
-        path =  uri[uri.find("://")+3:]
+def makedirs(uri, mode=0755):
+    if uri.find("://") != -1:
+        path = uri[uri.find("://") + 3:]
     else:
         path = uri
     if not os.path.exists(path):
@@ -207,32 +207,32 @@ def encode(s, charset="utf-8"):
     except UnicodeError:
         return (s + " " + _("[Invalid Encoding]")).encode(charset, "replace")
 
-def pls_rebuild_uri(base_uri,uri):
+def pls_rebuild_uri(base_uri, uri):
     base_uri = base_uri[:base_uri.rfind("/")]
     if uri.find("://") != -1:
         return uri
     elif  uri[0] == "/":
-        return "file://"+quote(uri)
+        return "file://" + quote(uri)
     else:
-        return base_uri+"/"+quote(uri)
+        return base_uri + "/" + quote(uri)
     
 """ Return all folder in a folder excepted hidden one """
 def get_folder_in_folder(dir):
     dirs = set()
     alldirs = [ get_path_from_uri(dir) ]
     for mdir in alldirs:
-        for dirpath, dirs, names in os.walk(mdir):
+        for dirpath, dirs, _names in os.walk(mdir):
             [ dirs.remove(dir) for dir in dirs if dir[0] == "." ]
-            [ alldirs.append(os.path.realpath(os.path.join(dirpath,dir))) for dir in dirs if os.path.islink(os.path.join(dirpath,dir)) ]
-            dirs.add(get_uri_from_path(os.path.join(dirpath,dirs)))
+            [ alldirs.append(os.path.realpath(os.path.join(dirpath, dir))) for dir in dirs if os.path.islink(os.path.join(dirpath, dir)) ]
+            dirs.add(get_uri_from_path(os.path.join(dirpath, dirs)))
             while gtk.events_pending():gtk.main_iteration()
     return dirs
 
 """ Return all uri in a folder excepted hidden one """
 def parse_folder(dir):
     dir = get_path_from_uri(dir)
-    uris = [ get_uri_from_path(os.path.join(dir,name)) for name in os.listdir(dir) if name[0] != "." and os.path.isfile(os.path.join(dir,name)) ]
-    print "W:Utils:ParseFolder:",len(uris),"founds"
+    uris = [ get_uri_from_path(os.path.join(dir, name)) for name in os.listdir(dir) if name[0] != "." and os.path.isfile(os.path.join(dir, name)) ]
+    print "W:Utils:ParseFolder:", len(uris), "founds"
     return uris
 
 """ 
@@ -250,13 +250,12 @@ def parse_uris(uris, follow_folder=True, follow_playlist=True, callback=None, *a
     for uri in uris:
         #Check file exists only is file is local to speed parsing of shared/remote file
         uri = unquote(uri)
-        if uri and uri.strip()!="" and exists(uri):
+        if uri and uri.strip() != "" and exists(uri):
             ext = get_ext(uri)
-            info = None
             try:
-                mimetype = get_mime_type(uri)
+                mime_type = get_mime_type(uri)
             except:
-                logger.exception("failed to read file info from %s",uri)
+                logger.logexception("failed to read file info from %s", uri)
                 continue
 
             is_pls = False
@@ -273,21 +272,21 @@ def parse_uris(uris, follow_folder=True, follow_playlist=True, callback=None, *a
             is_xspf = is_xspf or (ext == ".xspf")
                 
             if islocaldir(uri) and follow_folder:
-                valid_uris.extend(parse_uris(parse_folder(uri),follow_folder,follow_playlist))
+                valid_uris.extend(parse_uris(parse_folder(uri), follow_folder, follow_playlist))
             elif follow_playlist and is_pls:
-                valid_uris.extend(parse_uris(get_uris_from_pls(uri),follow_folder,follow_playlist))
+                valid_uris.extend(parse_uris(get_uris_from_pls(uri), follow_folder, follow_playlist))
             elif follow_playlist and is_xspf:
-                valid_uris.extend(parse_uris(get_uris_from_xspf(uri),follow_folder,follow_playlist))
+                valid_uris.extend(parse_uris(get_uris_from_xspf(uri), follow_folder, follow_playlist))
             elif follow_playlist and is_m3u:
-                valid_uris.extend(parse_uris(get_uris_from_m3u(uri),follow_folder,follow_playlist))
+                valid_uris.extend(parse_uris(get_uris_from_m3u(uri), follow_folder, follow_playlist))
             elif get_scheme(uri) != "file" or file_is_supported(get_path_from_uri(uri)):
                 valid_uris.append(uri)
 
-    logger.info("parseuris found %s uris",len(valid_uris))
+    logger.loginfo("parseuris found %s uris", len(valid_uris))
     if callback:
         def launch_callback(callback, uris, args, kwargs):
             callback(uris, *args, **kwargs)
-        gobject.idle_add(launch_callback, callback,list(valid_uris), args_cb, kwargs_cb)
+        gobject.idle_add(launch_callback, callback, list(valid_uris), args_cb, kwargs_cb)
     else:
         return valid_uris
 
@@ -303,9 +302,9 @@ def get_uris_from_m3u(uri):
     content = read_entire_file(uri)
     lines = content.splitlines()
     for line in lines:
-        if not line.startswith("#") and line.strip()!="":
+        if not line.startswith("#") and line.strip() != "":
             uris.append(line.strip())
-    uris = [pls_rebuild_uri(uri,u) for u in uris]
+    uris = [pls_rebuild_uri(uri, u) for u in uris]
     return uris
     
 """ Return uri in a pls playlist """
@@ -314,12 +313,12 @@ def get_uris_from_pls(uri):
     content = read_entire_file(uri)
     lines = content.splitlines()
     for line in lines:
-        if line.lower().startswith("file") and line.find("=")!=-1:
-           uris.append(line[line.find("=")+1:].strip())
-    uris = [pls_rebuild_uri(uri,u) for u in uris]
+        if line.lower().startswith("file") and line.find("=") != -1:
+            uris.append(line[line.find("=") + 1:].strip())
+    uris = [pls_rebuild_uri(uri, u) for u in uris]
     return uris
 
-from xml.sax import parseString, handler, SAXParseException
+from xml.sax import parseString, handler
 class XSPFParser(handler.ContentHandler):
     def __init__(self):
         self.uris = []
@@ -336,18 +335,17 @@ class XSPFParser(handler.ContentHandler):
 
 """ Return uri in a xspf playlist """
 def get_uris_from_xspf(uri):
-    uris = []
     try: 
         handler = XSPFParser()
         parseString(read_entire_file(uri), handler)
     except:
-        logger.exception("Failed to parse %s",uri)
+        logger.logexception("Failed to parse %s", uri)
         return []
     else:
         return handler.uris
 
 def get_uris_from_asx(uri):
-    uri_list= []
+    uri_list = []
     uri_asx_list = [uri]
     while len(uri_asx_list) > 0:
         uri = uri_asx_list.pop()
@@ -360,21 +358,21 @@ def get_uris_from_asx(uri):
                 for ref in d.getElementsByTagName('ref')
                 if ref.hasAttribute('href') ])
         for link in links:
-            if link[-4:] == ".asx" or (link.find("?") != -1 and link[link.find("?")-4:link.find("?")] == ".asx"):
+            if link[-4:] == ".asx" or (link.find("?") != -1 and link[link.find("?") - 4:link.find("?")] == ".asx"):
                 uri_asx_list.append(link)
             else:
                 uri_list.append(link)
 #    print "get_uris_from_asx",uri_list
     return uri_list
 
-def async_get_uris_from_plain_text(content, callback=None, *args_cb, **kwargs):
+def async_get_uris_from_plain_text(content, callback=None, *args_cb, **kwargs_cb):
     """ Return uri found in a string
 For now return uri only if one line is one uri
 use parse uri to follow directory and playlist """
     uris = [ line.strip() for line in content.splitlines() if line.strip() ]
     async_parse_uris(uris, True, True, callback, *args_cb, **kwargs_cb)
 
-def get_uris_from_plain_text(content, callback=None, *args_cb, **kwargs):
+def get_uris_from_plain_text(content, callback=None, *args_cb, **kwargs_cb):
     """ Return uri found in a string
 For now return uri only if one line is one uri
 use parse uri to follow directory and playlist """
@@ -385,58 +383,58 @@ def move_to_trash(uri):
     path = get_path_from_uri(uri)
     path = os.path.realpath(os.path.expanduser(path))
     if not os.path.exists(path): 
-        logger.debug("File %s doesn't exists",path)
+        logger.logdebug("File %s doesn't exists", path)
         return False
     #find the trash folder
     home_dir = os.path.realpath(os.path.expanduser("~"))
     dirs_name = path.split("/")
-    dirs_name = filter(lambda name: name!="",dirs_name)
+    dirs_name = filter(lambda name: name != "", dirs_name)
     trash_dir = None
-    r = range(0,len(dirs_name))
+    r = range(0, len(dirs_name))
     r.reverse()
     for i in r:
-        tmp_path = os.path.realpath("/"+"/".join(dirs_name[:i]))
+        tmp_path = os.path.realpath("/" + "/".join(dirs_name[:i]))
         if tmp_path == home_dir:
-            trash_dir = home_dir+"/.local/share/Trash"
-            trash_dir = os.environ.get("XDG_DATA_HOME",trash_dir)
+            trash_dir = home_dir + "/.local/share/Trash"
+            trash_dir = os.environ.get("XDG_DATA_HOME", trash_dir)
             break
         elif os.path.ismount(tmp_path):
-            trash_dir = tmp_path+"/.Trash-%d"%os.getuid()
+            trash_dir = tmp_path + "/.Trash-%d" % os.getuid()
             break
         else: continue
     if not trash_dir:
-        logger.error("trash dir not found")
+        logger.logerror("trash dir not found")
         return False
 
     for subdir in ["files", "info"]:
-        if not os.path.exists(trash_dir+"/"+subdir):
+        if not os.path.exists(trash_dir + "/" + subdir):
             try:
-                os.makedirs(trash_dir+"/"+subdir,0700)
+                os.makedirs(trash_dir + "/" + subdir, 0700)
             except: 
-                logger.warn("Failed to create trash dir %s",trash_dir+"/"+subdir)
+                logger.logwarn("Failed to create trash dir %s", trash_dir + "/" + subdir)
                 return False
 
-    if path.rfind("/")!=-1:
-        filename = path[path.rindex("/")+1:]
+    if path.rfind("/") != -1:
+        filename = path[path.rindex("/") + 1:]
 
     deleteddate = time.strftime("%Y-%M-%dT%H:%M:%S")
-    destpath = trash_dir+"/files/"+filename
-    infopath = trash_dir+"/info/"+filename+".trashinfo"
+    destpath = trash_dir + "/files/" + filename
+    infopath = trash_dir + "/info/" + filename + ".trashinfo"
     try:
         shutil.move(path, destpath)
-        f = open(infopath,"w")
-        f.write("[Trash Info]\nPath=%s\nDeletionDate=%s\n"%(quote(path),deleteddate))
+        f = open(infopath, "w")
+        f.write("[Trash Info]\nPath=%s\nDeletionDate=%s\n" % (quote(path), deleteddate))
         f.close()
     except: 
-        logger.exception("Failed to move to trash %s", path)
+        logger.logexception("Failed to move to trash %s", path)
         return False
     else: return True
 
-def download_iterator(remote_uri, local_uri, buffer_len = 4096):
+def download_iterator(remote_uri, local_uri, buffer_len=4096, timeout=DEFAULT_TIMEOUT):
     try:
-        logger.info("download %s start",remote_uri)
-        handle_read = urlopen(remote_uri)
-        handle_write = file(get_path_from_uri(local_uri),"w")
+        logger.loginfo("download %s start", remote_uri)
+        handle_read = urlopen(remote_uri, timeout=timeout)
+        handle_write = file(get_path_from_uri(local_uri), "w")
         info = handle_read.info()
     
         try: totalsize = int(info.getheader("content-length"))
@@ -446,31 +444,30 @@ def download_iterator(remote_uri, local_uri, buffer_len = 4096):
         handle_write.write(data)
         currentsize += len(data)
         
-        last_event = None
         while data:
             data = handle_read.read(buffer_len)
             currentsize += len(data)
             handle_write.write(data)
-            percent = currentsize*100/totalsize
-            yield (totalsize,currentsize,percent)
+            percent = currentsize * 100 / totalsize
+            yield (totalsize, currentsize, percent)
 
         handle_read.close()
         handle_write.close()
-        logger.info("download %s finish"%remote_uri)
+        logger.loginfo("download %s finish" % remote_uri)
     except GeneratorExit:
         try: unlink(local_uri)
         except: pass
     except:
-        logger.exception("Error while downloading %s",remote_uri)
+        logger.logexception("Error while downloading %s", remote_uri)
         try: unlink(local_uri)
         except: pass
         raise IOError
 
-def download(remote_uri, local_uri, buffer_len = 4096):
+def download(remote_uri, local_uri, buffer_len=4096, timeout=DEFAULT_TIMEOUT):
     try:
-        logger.info("download %s start",remote_uri)
-        handle_read = urlopen(remote_uri)
-        handle_write = file(get_path_from_uri(local_uri),"w")
+        logger.loginfo("download %s start", remote_uri)
+        handle_read = urlopen(remote_uri, timeout=timeout)
+        handle_write = file(get_path_from_uri(local_uri), "w")
         
         data = handle_read.read(buffer_len)
         handle_write.write(data)
@@ -481,12 +478,13 @@ def download(remote_uri, local_uri, buffer_len = 4096):
 
         handle_read.close()
         handle_write.close()
-        logger.info("download %s finish"%remote_uri)
+        logger.loginfo("download %s finish" % remote_uri)
     except:
-        logger.exception("Error while downloading %s",remote_uri)
+        logger.logexception("Error while downloading %s", remote_uri)
         try: unlink(local_uri)
         except: pass
         return False
     if not exists(local_uri): 
         return False
     return True
+
