@@ -21,14 +21,11 @@
 ###
 
 
-import os
 import gtk
-import gobject
 
 from config import config
 
 from helper import Dispatcher
-from action_manager import ActionManager
 from player import Player
 
 class PlayerPlaylistControl(gtk.HBox):
