@@ -22,7 +22,6 @@
 
 
 import os
-import sys
 import gobject
 import gtk
 import pango
@@ -35,7 +34,7 @@ import stock
 from proxy import discover_http_proxy
 
 import amazon
-proxy=discover_http_proxy()
+proxy = discover_http_proxy()
 if proxy.has_key("http"):
     amazon.setProxy(proxy["http"])
 
@@ -47,7 +46,6 @@ from player import Player
 from library import ListenDB
 from logger import Logger
 
-from helper import Dispatcher
 from cover_manager import CoverManager, COVER_SIZE, COVER_SAVE_SIZE
 
 from vfs import urlopen
@@ -55,17 +53,17 @@ from vfs import urlopen
 PREVIEW_SIZE = gtk.icon_size_register("preview-cover", COVER_SIZE["x"], COVER_SIZE["y"])
         
 class CoverButton(gtk.EventBox):
-    def __init__(self,halign="top",valign="right"):
-        super(CoverButton,self).__init__()
+    def __init__(self, halign="top", valign="right"):
+        super(CoverButton, self).__init__()
         
-        self.halign=halign
-        self.valign=valign
+        self.halign = halign
+        self.valign = valign
         #self.set_alignment(0.5,0.5)
         #self.set_relief(gtk.RELIEF_NONE)
 
-        image = gtk.image_new_from_stock(stock.ALBUM_ART, PREVIEW_SIZE )
+        image = gtk.image_new_from_stock(stock.ALBUM_ART, PREVIEW_SIZE)
         image.set_size_request(COVER_SIZE["x"], COVER_SIZE["y"])
-        image.set_alignment(0.5,0.5)
+        image.set_alignment(0.5, 0.5)
 
         f = gtk.Frame()
         f.add(image)
@@ -75,7 +73,7 @@ class CoverButton(gtk.EventBox):
 
         self.set_tooltip_text(_("Right click: change cover\nLeft click: show big cover"))
 
-        ListenDB.connect("simple-changed",self.update_cover)
+        ListenDB.connect("simple-changed", self.update_cover)
 
         self.current_song = None
         
@@ -102,50 +100,50 @@ class CoverButton(gtk.EventBox):
             self.next_cover_to_download = None 
             self.condition.release()
             
-            self.set_current_cover(True,next_cover_to_download)
+            self.set_current_cover(True, next_cover_to_download)
         
     def __press(self, widget, event):
-        if event.button==1:
+        if event.button == 1:
             if self.current_song:
-                self.win_preview.child.set_from_pixbuf(gtk.gdk.pixbuf_new_from_file(CoverManager.get_cover(self.current_song, False) ) )
+                self.win_preview.child.set_from_pixbuf(gtk.gdk.pixbuf_new_from_file(CoverManager.get_cover(self.current_song, False)))
                 self.win_preview.realize()
-                self.win_preview.show_all()
-                x,y = self.child.child.window.get_origin()
+                x, y = self.child.child.window.get_origin()
                 if self.halign != "top":
                     y = y - self.win_preview.allocation.height + self.child.child.allocation.height
                 if self.valign != "left":
                     x = x - self.win_preview.allocation.width + self.child.child.allocation.width
-                x = x+self.child.child.allocation.x
-                y = y+self.child.child.allocation.y
-                self.win_preview.move(int(x),int(y))
+                x = x + self.child.child.allocation.x
+                y = y + self.child.child.allocation.y
+                self.win_preview.move(int(x), int(y))
                 self.win_preview.show_all()
             return True
-        elif event.button==3:
+        elif event.button == 3:
             if self.current_song:     
                 self.win_preview.hide_all()
                 return True
         return False
             
     def __release(self, widget, event):   
-        if event.button==1:    
+        if event.button == 1:    
             if self.current_song:     
                 self.win_preview.hide_all()
             return True
-        elif event.button==3:
+        elif event.button == 3:
             self.open_cover_dialog()
             return True
         else:
             return False
         
-    def open_cover_dialog(self,widget=None):
+    def open_cover_dialog(self, widget=None):
         if self.current_song: CoverWindow(self.current_song)
 
-    def update_default_cover(self,widget,song):
+    def update_default_cover(self, widget, song):
         if not self.current_song or CoverManager.get_cover_search_str(self.current_song) != CoverManager.get_cover_search_str(song):
-            self.child.child.set_from_pixbuf(CoverManager.DEFAULT_COVER_PIXBUF_BIG)
+            pixbuf = CoverManager.get_pixbuf_from_album("")
+            self.child.child.set_from_pixbuf(pixbuf)
         
-    def update_cover(self,widget,songs):
-        if isinstance(songs,list):
+    def update_cover(self, widget, songs):
+        if isinstance(songs, list):
             if self.current_song in songs:
                 self.current_song = songs[songs.index(self.current_song)]
         else:
@@ -159,7 +157,7 @@ class CoverButton(gtk.EventBox):
                 self.condition.release()
 
 
-    def set_current_cover(self, try_amazon=True, force_song=None ):
+    def set_current_cover(self, try_amazon=True, force_song=None):
         if not force_song: force_song = self.current_song
 
         filename = CoverManager.get_cover(force_song, try_amazon)
@@ -170,7 +168,7 @@ class CoverButton(gtk.EventBox):
         else:
             """ If try amazon the call is in thread then use of idle_add """
             if try_amazon:
-                gobject.idle_add( self.child.child.set_from_pixbuf,pixbuf)
+                gobject.idle_add(self.child.child.set_from_pixbuf, pixbuf)
                 del pixbuf
             else:
                 self.child.child.set_from_pixbuf(pixbuf)
@@ -179,60 +177,60 @@ class CoverButton(gtk.EventBox):
 
 class PopupWindowCoverButton(gtk.Window):
     def __init__(self):    
-        super(PopupWindowCoverButton,self).__init__(gtk.WINDOW_POPUP)
+        super(PopupWindowCoverButton, self).__init__(gtk.WINDOW_POPUP)
         self.add(CoverButton())
         
         self.id_hide_preview = None
             
-        self.connect("enter-notify-event",self.stop_timeout_hide_cover)
-        self.connect("leave-notify-event",self.timeout_hide_cover)
-        self.child.child.connect("enter-notify-event",self.stop_timeout_hide_cover)
-        self.child.child.connect("leave-notify-event",self.timeout_hide_cover)
-        self.child.win_preview.connect("show",self.stop_timeout_hide_cover)
-        self.child.win_preview.connect("leave-notify-event",self.timeout_hide_cover)
+        self.connect("enter-notify-event", self.stop_timeout_hide_cover)
+        self.connect("leave-notify-event", self.timeout_hide_cover)
+        self.child.child.connect("enter-notify-event", self.stop_timeout_hide_cover)
+        self.child.child.connect("leave-notify-event", self.timeout_hide_cover)
+        self.child.win_preview.connect("show", self.stop_timeout_hide_cover)
+        self.child.win_preview.connect("leave-notify-event", self.timeout_hide_cover)
     
-    def show_cover(self,song):
+    def show_cover(self, song):
         self.stop_timeout_hide_cover()
-        self.child.update_cover(None,song)
+        self.child.update_cover(None, song)
     
-    def timeout_hide_cover(self,*param):
-		self.id_hide_preview = gobject.timeout_add(500,self.hide_cover)
+    def timeout_hide_cover(self, *param):
+        self.id_hide_preview = gobject.timeout_add(500, self.hide_cover)
         
-    def hide_cover(self,*param):
+    def hide_cover(self, *param):
         self.hide_all()
         self.child.win_preview.hide_all()
         
-    def stop_timeout_hide_cover(self,*param):
-        if self.id_hide_preview!=None: 
+    def stop_timeout_hide_cover(self, *param):
+        if self.id_hide_preview != None: 
             gobject.source_remove(self.id_hide_preview)
             self.hide_cover()
         
 class PlayerCoverButton(CoverButton):
     def __init__(self):
-        super(PlayerCoverButton,self).__init__(valign="left")
+        super(PlayerCoverButton, self).__init__(valign="left")
     
-        Player.connect("new-song",self.update_cover)
-        Player.connect("instant-new-song",self.instant_update_cover)
+        Player.connect("new-song", self.update_cover)
+        Player.connect("instant-new-song", self.instant_update_cover)
        
-    def instant_update_cover(self,widget,song):
+    def instant_update_cover(self, widget, song):
         if not CoverManager.get_cover(song, False):
-            self.update_default_cover(widget,song)
+            self.update_default_cover(widget, song)
         else:
-            self.update_cover(widget,song)
+            self.update_cover(widget, song)
 
-class CoverWindow(WindowBase,Logger):
-    def __init__(self,current_song):
+class CoverWindow(WindowBase, Logger):
+    def __init__(self, current_song):
         self.song = Song(current_song)
         self.song.set_type(current_song.get_type())
         image = gtk.Image()
-        image.set_from_file( CoverManager.get_cover(self.song, False))
+        image.set_from_file(CoverManager.get_cover(self.song, False))
         f = gtk.Frame()
         f.set_shadow_type(gtk.SHADOW_IN)
         f.add(image)
-        WindowBase.__init__(self,_("Search an album cover"),None,())
+        WindowBase.__init__(self, _("Search an album cover"), None, ())
         
         default_search = ""
-        if self.song.get("artist"): default_search += utils.filter_info_song(self.song.get("artist")).encode("utf-8")+" "
+        if self.song.get("artist"): default_search += utils.filter_info_song(self.song.get("artist")).encode("utf-8") + " "
         default_search += CoverManager.get_cover_search_str(self.song)
         default_search = utils.remove_accents(default_search)
         
@@ -241,25 +239,25 @@ class CoverWindow(WindowBase,Logger):
         self.select.append_text(_("From Amazon"))
         self.select.append_text(_("From Google Image"))
         self.select.set_active(0)
-        self.select.connect("changed",self.change_source)
+        self.select.connect("changed", self.change_source)
         
         self.entry = gtk.Entry()
-        self.entry.set_text(default_search.replace("+"," "))
-        self.entry.set_size_request(300,-1)
-        self.entry.connect("activate",self.on_search,1)
+        self.entry.set_text(default_search.replace("+", " "))
+        self.entry.set_size_request(300, -1)
+        self.entry.connect("activate", self.on_search, 1)
 
         btn_search = gtk.Button(stock=gtk.STOCK_FIND)
-        btn_search.connect("clicked",self.on_search,1)
-        hbox = gtk.HBox(False,12)
-        hbox.pack_start(self.entry,True,True)
-        hbox.pack_start(self.select,False,False)
-        hbox.pack_start(btn_search,False,False)
+        btn_search.connect("clicked", self.on_search, 1)
+        hbox = gtk.HBox(False, 12)
+        hbox.pack_start(self.entry, True, True)
+        hbox.pack_start(self.select, False, False)
+        hbox.pack_start(btn_search, False, False)
 
-        self.box_resultat = gtk.Table(4,2)
+        self.box_resultat = gtk.Table(4, 2)
 
-        vbox = gtk.VBox(False,0)
-        vbox.pack_start(hbox,False,False)
-        vbox.pack_start(self.box_resultat,False,False)
+        vbox = gtk.VBox(False, 0)
+        vbox.pack_start(hbox, False, False)
+        vbox.pack_start(self.box_resultat, False, False)
         self.add_widget(vbox)
         self.add_button(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL)
         self.add_button(gtk.STOCK_DELETE, gtk.RESPONSE_APPLY)
@@ -268,21 +266,21 @@ class CoverWindow(WindowBase,Logger):
         self.add_button(gtk.STOCK_GO_FORWARD, gtk.RESPONSE_REJECT)
 
         self.label_error = gtk.Label(_("No result for this request"))
-        self.label_error.set_alignment(0.5,0.5)
-        self.label_error.set_size_request(-1,200)
+        self.label_error.set_alignment(0.5, 0.5)
+        self.label_error.set_size_request(-1, 200)
         
         self.label_wait = gtk.Label(_("Please wait..."))
-        self.label_wait.set_alignment(0.5,0.5)
-        self.label_wait.set_size_request(-1,200)
+        self.label_wait.set_alignment(0.5, 0.5)
+        self.label_wait.set_size_request(-1, 200)
 
         self.label_start = gtk.Label(" ")
-        self.label_start.set_alignment(0.5,0.5)
-        self.label_start.set_size_request(-1,200)
+        self.label_start.set_alignment(0.5, 0.5)
+        self.label_start.set_size_request(-1, 200)
 
-        self.box_resultat.resize(1,1)
+        self.box_resultat.resize(1, 1)
         self.box_resultat.attach(self.label_start, 0, 1, 0, 1)
 
-        self.download_thread = WebFetchThread(1024,self.fail_fetch)
+        self.download_thread = WebFetchThread(1024, self.fail_fetch)
 
         self.win_preview = gtk.Window(gtk.WINDOW_POPUP)
         self.win_preview.add(gtk.Image())
@@ -292,122 +290,122 @@ class CoverWindow(WindowBase,Logger):
         self.action_area.get_children()[0].set_sensitive(False)
         self.action_area.get_children()[1].set_sensitive(False)
         reponse = self.run()
-        while reponse not in [gtk.RESPONSE_CANCEL,gtk.RESPONSE_DELETE_EVENT]:
+        while reponse not in [gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT]:
             if reponse == gtk.RESPONSE_NO:
-                self.on_search(None,self.current_page-1)
+                self.on_search(None, self.current_page - 1)
             if reponse == gtk.RESPONSE_REJECT:
-                self.on_search(None,self.current_page+1)
+                self.on_search(None, self.current_page + 1)
             if reponse == gtk.RESPONSE_YES:
                 self.destroy()
                 AlbumCoverWindow(self.song)
                 return
             if reponse == gtk.RESPONSE_APPLY:
-                new_file = CoverManager.get_cover_path(song)
+                new_file = CoverManager.get_cover_path(self.song)
                 if os.path.exists(new_file):
-                     os.unlink(new_file)
-                pixbuf = CoverManager.DEFAULT_COVER_PIXBUF_BIG
-                pixbuf.save(new_file+".#disable#", "jpeg", {"quality":"85"})
+                    os.unlink(new_file)
+                pixbuf = CoverManager.get_pixbuf_from_album("")
+                pixbuf.save(new_file + ".#disable#", "jpeg", {"quality":"85"})
                 ListenDB.set_property(self.song, {})
                 self.destroy()
                 return
             reponse = self.run()
         self.destroy()
     
-    def fail_fetch(self,*args):
+    def fail_fetch(self, *args):
         self.current_page = 1
         self.box_resultat.foreach(self.box_resultat.remove)
-        self.box_resultat.resize(1,1)
+        self.box_resultat.resize(1, 1)
         self.box_resultat.attach(self.label_error, 0, 1, 0, 1)    
         self.action_area.get_children()[1].set_sensitive(False)
         self.action_area.get_children()[0].set_sensitive(False)
         self.show_all()
         self.loginfo("failed retrieve amazon or google image information")
         
-    def change_source(self,w):
+    def change_source(self, w):
         self.current_page = 1
-        self.on_search(None,1)
+        self.on_search(None, 1)
         
-    def on_search(self,btn,page):
+    def on_search(self, btn, page):
         self.box_resultat.foreach(self.box_resultat.remove)    
-        self.box_resultat.resize(1,1)
+        self.box_resultat.resize(1, 1)
         self.box_resultat.attach(self.label_wait, 0, 1, 0, 1)    
         self.action_area.get_children()[1].set_sensitive(False)
         self.action_area.get_children()[0].set_sensitive(False)    
         
         self.show_all()
-        if self.select.get_active()==0:
-            gobject.idle_add(self.on_search_amazon,page)   
+        if self.select.get_active() == 0:
+            gobject.idle_add(self.on_search_amazon, page)   
         else:
-            gobject.idle_add(self.on_search_google,page)  
+            gobject.idle_add(self.on_search_google, page)  
         
         
-    def on_search_google(self,page):
+    def on_search_google(self, page):
         art = self.entry.get_text().encode('utf-8')   
-        if page%2==0:
-            g_page = (page-1)*16
+        if page % 2 == 0:
+            g_page = (page - 1) * 16
         else:
-            g_page = (page-2)*16
+            g_page = (page - 2) * 16
         
-        url = "http://images.google.com/images?svnum=10&hl=fr&lr=&start=%d&safe=off&q=%s"%(g_page,quote(art))
+        url = "http://images.google.com/images?svnum=10&hl=fr&lr=&start=%d&safe=off&q=%s" % (g_page, quote(art))
         
-        self.download_thread.fetch_url(url,self.on_search_google_cb,page)
+        self.download_thread.fetch_url(url, self.on_search_google_cb, page)
             
-    def on_search_google_cb(self,html_handler,page):
+    def on_search_google_cb(self, html_handler, page):
         
         html = html_handler.read()
-        js_images = re.findall('\[\"/imgres[^"]*",\"[^"]*",\"[^"]*",\"([^"]*)",\"[^"]*",\"[^"]*",\"([^"]*)",\"[^"]*",\"[^"]*",\"([^"]*)",',html, re.S)
+        js_images = re.findall('\[\"/imgres[^"]*",\"[^"]*",\"[^"]*",\"([^"]*)",\"[^"]*",\"[^"]*",\"([^"]*)",\"[^"]*",\"[^"]*",\"([^"]*)",', html, re.S)
         if not js_images : 
             self.logwarn("Perhaps Google page structure has changed")
             self.fail_fetch()
             return 
 
-        mid = len(js_images)/2
-        if page%2==0:
-            js_images = js_images[ : mid-1 ]
+        mid = len(js_images) / 2
+        if page % 2 == 0:
+            js_images = js_images[ : mid - 1 ]
         else:
             js_images = js_images[ mid : ]
 
         items = []
         for jsimg in js_images:
             info = jsimg[1]
-            info = info.replace('\\x3cb\\x3e','')
-            info = info.replace('\\x3c/b\\x3e','')
+            info = info.replace('\\x3cb\\x3e', '')
+            info = info.replace('\\x3c/b\\x3e', '')
             url = str(jsimg[0])
             title = jsimg[2]
             items.append((url, title , info))            
-        self.populate(page,items)
+        self.populate(page, items)
 
 
-    def on_search_amazon(self,page):
+    def on_search_amazon(self, page):
         art = utils.remove_accents(self.entry.get_text().encode('utf-8'))
 
         try: 
-            pages = amazon.ItemSearch(art, "Music", Condition="All", MerchantId="All", Availability=None, ResponseGroup="Images,Request,Small" )
+            pages = amazon.ItemSearch(art, "Music", Condition="All", MerchantId="All", Availability=None, ResponseGroup="Images,Request,Small")
         except:
             self.fail_fetch()
             return
 
         items = []
-        for i in range(page,page+10):
+        for i in range(page, page + 10):
             try: p = pages[i]
             except IndexError:
                 break;
             artist = ""
-            if hasattr(p,"Artist"): artist = p.Artist
-            if isinstance(artist,list): artist = artist[0] 
+            if hasattr(p, "Artist"): artist = p.Artist
+            if isinstance(artist, list): artist = artist[0] 
 
-            if hasattr(p,"Creator"): artist = p.Creator
+            if hasattr(p, "Creator"): artist = p.Creator
             if not hasattr(p, "LargeImage"): continue
 
-            try: items.append((p.LargeImage.URL,p.Title,artist))
+            try: items.append((p.LargeImage.URL, p.Title, artist))
             except:
-                self.logexception("failed parse amazon information %s",dir(p))
+                self.logexception("failed parse amazon information %s", dir(p))
             
-        self.populate(page,items)
+        self.populate(page, items)
         
                 
 
-    def populate(self,page,items):
+    def populate(self, page, items):
         self.box_resultat.foreach(self.box_resultat.remove)     
         self.current_page = page
         i = 0
@@ -417,32 +415,32 @@ class CoverWindow(WindowBase,Logger):
             self.action_area.get_children()[1].set_sensitive(False)
         else:
             self.action_area.get_children()[1].set_sensitive(True)
-        if len(items)<10:
+        if len(items) < 10:
             self.action_area.get_children()[0].set_sensitive(False)
         else:
             self.action_area.get_children()[0].set_sensitive(True)
 
-        height= int(round(len(items)/2,1))
-        if len(items)%2!=0: height += 1
+        height = int(round(len(items) / 2, 1))
+        if len(items) % 2 != 0: height += 1
         #if height>8 : height=8
-        self.box_resultat.resize(height,2)
+        self.box_resultat.resize(height, 2)
 
-        for url,label1,label2 in items:
+        for url, label1, label2 in items:
 
             
             image = gtk.Image()
             image.fullsize = None
             loader = gtk.gdk.PixbufLoader()
             loader.set_size(COVER_SAVE_SIZE["x"], COVER_SAVE_SIZE["y"])
-            def on_closed(loader,image):
-                if image!=None:
+            def on_closed(loader, image):
+                if image != None:
                     image.fullsize = loader.get_pixbuf()
-                    if image.fullsize!=None:
-                        image.set_from_pixbuf(image.fullsize.scale_simple(40,40, gtk.gdk.INTERP_NEAREST))
-            loader.connect("closed", on_closed ,image)
+                    if image.fullsize != None:
+                        image.set_from_pixbuf(image.fullsize.scale_simple(40, 40, gtk.gdk.INTERP_NEAREST))
+            loader.connect("closed", on_closed , image)
             
-            def thread(url,loader,image):
-                def write(loader,data,image):
+            def thread(url, loader, image):
+                def write(loader, data, image):
                     try:
                         loader.write(data)
                         loader.close()
@@ -458,35 +456,35 @@ class CoverWindow(WindowBase,Logger):
                 else:
                     data = f.read()
                     f.close()
-                    gobject.idle_add(write,loader,data,image)
+                    gobject.idle_add(write, loader, data, image)
                 
-            t = threading.Thread(target=thread,args=(url,loader,image))
+            t = threading.Thread(target=thread, args=(url, loader, image))
             t.setDaemon(True)
             t.start()
             
-            image.set_size_request(40,40)
+            image.set_size_request(40, 40)
             label = gtk.Label()
-            label.set_markup("<b>"+utils.xmlescape(label1)+"</b>\n"+utils.xmlescape(label2))
-            label.set_property("ellipsize",pango.ELLIPSIZE_END)
-            label.set_alignment(0,0.5)
-            box= gtk.HBox(False,6)
-            box.pack_start(image,False,False)
-            box.pack_start(label,True,True)
+            label.set_markup("<b>" + utils.xmlescape(label1) + "</b>\n" + utils.xmlescape(label2))
+            label.set_property("ellipsize", pango.ELLIPSIZE_END)
+            label.set_alignment(0, 0.5)
+            box = gtk.HBox(False, 6)
+            box.pack_start(image, False, False)
+            box.pack_start(label, True, True)
 
             btn_cover = gtk.Button()#"test-%d"%i)
-            btn_cover.set_alignment(0.5,0.5)
-            btn_cover.connect("clicked",self.on_cover_clicked)#,image_path)
+            btn_cover.set_alignment(0.5, 0.5)
+            btn_cover.connect("clicked", self.on_cover_clicked)#,image_path)
         
             btn_cover.connect('button-press-event', self.__press)
             btn_cover.connect('button-release-event', self.__release)
         
             btn_cover.set_relief(gtk.RELIEF_NONE)
             btn_cover.add(box)
-            right_attach = left_attach+1
-            bottom_attach = top_attach+1
+            right_attach = left_attach + 1
+            bottom_attach = top_attach + 1
             self.box_resultat.attach(btn_cover, left_attach, right_attach, top_attach, bottom_attach)
             i += 1
-            if i%2==0:
+            if i % 2 == 0:
                 top_attach += 1
                 left_attach = 0
             else:
@@ -494,50 +492,50 @@ class CoverWindow(WindowBase,Logger):
         self.show_all()
       
     def __press(self, widget, event):
-        if event.button==3:
+        if event.button == 3:
             if widget.child.get_children()[0].fullsize:
                 self.win_preview.child.set_from_pixbuf(widget.child.get_children()[0].fullsize)
-                x,y = self.window.get_origin()
-                self.win_preview.move(int(x+widget.child.get_children()[0].allocation.x),int(y+widget.child.get_children()[0].allocation.y))
+                x, y = self.window.get_origin()
+                self.win_preview.move(int(x + widget.child.get_children()[0].allocation.x), int(y + widget.child.get_children()[0].allocation.y))
                 self.win_preview.show_all()
             return True
         else:
             return False
             
     def __release(self, widget, event):   
-        if event.button==3: 
+        if event.button == 3: 
             if widget.child.get_children()[0].fullsize:    
                 self.win_preview.hide_all()
             return True
         else:
             return False  
         
-    def on_cover_clicked(self,btn):
+    def on_cover_clicked(self, btn):
         pixbuf = btn.get_children()[0].get_children()[0].fullsize
         CoverManager.remove_cover(self.song)
         new_file = CoverManager.get_cover_path(self.song)
         if os.path.exists(new_file):
-             os.unlink(new_file)
-        if os.path.exists(new_file+".#disable#"):
-             os.unlink(new_file+".#disable#")
+            os.unlink(new_file)
+        if os.path.exists(new_file + ".#disable#"):
+            os.unlink(new_file + ".#disable#")
         pixbuf.save(new_file, "jpeg", {"quality":"85"})
         del pixbuf
-        ListenDB.set_property(self.song,{"album":self.song.get("album")})
-        self.emit("response",gtk.RESPONSE_DELETE_EVENT)
+        ListenDB.set_property(self.song, {"album":self.song.get("album")})
+        self.emit("response", gtk.RESPONSE_DELETE_EVENT)
 
 class AlbumCoverWindow(gtk.FileChooserDialog):
-    def __init__(self,current_song):
+    def __init__(self, current_song):
         song = Song(current_song)
         song.set_type(current_song.get_type())
 
-        gtk.FileChooserDialog.__init__(self,_("Choose an album cover"), None,
+        gtk.FileChooserDialog.__init__(self, _("Choose an album cover"), None,
              gtk.FILE_CHOOSER_ACTION_OPEN,
-             (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN, gtk.RESPONSE_OK))
+             (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OPEN, gtk.RESPONSE_OK))
 
-        btn = self.add_button(_("Internet search"),gtk.RESPONSE_HELP)
+        btn = self.add_button(_("Internet search"), gtk.RESPONSE_HELP)
         btn.set_image(gtk.image_new_from_stock(gtk.STOCK_FIND, gtk.ICON_SIZE_LARGE_TOOLBAR))
 
-        if song.get("uri")!=None and song.get_scheme()=="file":
+        if song.get("uri") != None and song.get_scheme() == "file":
             open_folder = song.get_path()
             open_folder = open_folder[:open_folder.rfind("/")]
         else:
@@ -554,7 +552,7 @@ class AlbumCoverWindow(gtk.FileChooserDialog):
         ffilter.add_mime_type("image/svg+xml")
 
         self.add_filter(ffilter)
-        self.set_size_request(500,350)
+        self.set_size_request(500, 350)
         
         response = self.run()
         if response == gtk.RESPONSE_OK:
@@ -562,15 +560,17 @@ class AlbumCoverWindow(gtk.FileChooserDialog):
             pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(file, COVER_SAVE_SIZE["x"], COVER_SAVE_SIZE["y"])
             new_file = CoverManager.get_cover_path(song)
             if os.path.exists(new_file):
-                 os.unlink(new_file)
-            if os.path.exists(new_file+".#disable#"):
-                 os.unlink(new_file+".#disable#")
+                os.unlink(new_file)
+            if os.path.exists(new_file + ".#disable#"):
+                os.unlink(new_file + ".#disable#")
             pixbuf.save(new_file, "jpeg", {"quality":"85"})
             del pixbuf
             ListenDB.set_property(song, {})
             self.destroy()
         elif response == gtk.RESPONSE_HELP:
             self.destroy()
-            AmazonWindow(song)
+            CoverWindow(song)
         else:
             self.destroy()
+
+
