@@ -21,13 +21,11 @@
 ###
 
 
-
-import gobject
 import gtk
 import random
 
 from config import config
-from misc import * 
+from misc import Label, SimpleVBox, SimpleHBox
 from lastfm_service import lastfm_info
 from library import ListenDB
 from player import Player
@@ -182,7 +180,7 @@ class DynamicPlaylist(object):
             for song in songs:
                 artists[song.get("artist")]=song
     
-            songs = [( song.get("#playcount",0) - song.get("#skipcount",0), song) for artist,song in artists.iteritems()]
+            songs = [( song.get("#playcount",0) - song.get("#skipcount",0), song) for _artist ,song in artists.iteritems()]
             
             songs = songs[:max(200,len(songs)*10/100)]
             songs.sort()
