@@ -26,7 +26,7 @@
 
 import gobject
 import gtk
-from Xlib import display as Xdisplay, Xatom, protocol as Xprotocol, X
+from Xlib import display as Xdisplay, protocol as Xprotocol, X
 
 __all__ = ["TrayIcon"]
 
@@ -109,7 +109,7 @@ class TrayIcon(gtk.Plug):
 
     def on_realize(self,widget):
         screen = self.get_screen()
-        display = screen.get_display()
+        _display = screen.get_display()
         xdisplay = self.get_xdisplay()
         
         self.make_transparent(widget)
@@ -192,7 +192,6 @@ class TrayIcon(gtk.Plug):
 
     def get_orientation_property(self):
         assert(self.__manager_window != None)
-        xdisplay = self.get_xdisplay()
         result = self.__manager_window.get_property(self.orientation_atom,6,0L,32000L,0)
         if not result or not list(result.value): 
             return
@@ -230,12 +229,12 @@ class TrayIcon(gtk.Plug):
         self.send_manager_message(SYSTEM_TRAY_BEGIN_MESSAGE,self.get_id(),timeout, l, stamp)
         
         while l > 0:
-            xdisplay = display.Display()
+            xdisplay = Xdisplay.Display()
             if l > 20:
-                messagecur = message[20]
+                messagecut = message[20]
                 l -= 20
             else:
-                messagecur = message
+                messagecut = message
                 l = 0
             ev = Xprotocol.event.ClientMessage( \
                     window = self.get_id(), \
@@ -243,7 +242,7 @@ class TrayIcon(gtk.Plug):
                     data = (8, messagecut ) \
                     )
             message = message[20:]
-            dest = d.Display()
+            dest = Xdisplay.Display()
             dest.send_event(ev,X.StructureNotifyMask)
             dest.sync(False)
 
