@@ -26,7 +26,6 @@ import pango
 from library import ListenDB
 from player import Player
 
-from widget.misc import set_tip
 
 class PlayInfo(gtk.Label):
     def __init__(self):
@@ -38,7 +37,7 @@ class PlayInfo(gtk.Label):
         self.set_alignment(0,0.5)
         
         self.set_markup("<span size=\"large\"><b>"+_("No playing")+"</b></span>\n\n")
-        set_tip(self,_("No playing"))
+        self.set_tooltip_text(_("No playing"))
 
 
         Player.connect("instant-new-song",self.__new_song)
@@ -77,6 +76,9 @@ class PlayInfo(gtk.Label):
         if song.get("album"):
             tip += " - "+song.get_str("album")
             markup += song.get_str("album",True)
+            date =  song.get_str("date", True)
+            if date:
+                markup += " <i>(%s)</i>"%date
         elif song.get("info_supp"):
             markup +=  song.get_str("info_supp",True)
         elif buffering is not None and buffering <= 100:
@@ -84,5 +86,5 @@ class PlayInfo(gtk.Label):
         markup += "</span>"
 
         self.set_markup(markup)
-        set_tip(self,tip)
+        self.set_tooltip_text(tip)
         
