@@ -22,12 +22,12 @@
 
 import gobject
 import gtk
+
+import utils
 import stock
 from config import config
-import utils
 
 from dbus_manager import ListenDBus
-from hal import hal
 
 from player import Player
 
@@ -41,7 +41,6 @@ from library import ListenDB
 
 from widget.notify import Notify
 from widget.osd import Osd
-from widget.misc import ScrolledWindow
 from widget.playlist import PlaylistUI
 from widget.menubar import ListenMenuBar
 from widget.smart_playlist import SmartPlaylistWindow
@@ -52,24 +51,26 @@ from helper import Dispatcher
 from mmkeys_wrap import MMKeys
 from logger import Logger
 
-#TODO: Remove that
 from source.webradio import WindowNewRadio
 
+
 class Listen(gtk.Window,Logger):
-    __obscured = False
     __gsignals__ = {
         "ready" : (gobject.SIGNAL_RUN_LAST,
                 gobject.TYPE_NONE,
                 ())}
+        
     def __init__(self):
-        
-        #Start Audioscrobbler Session
-        
+                
         gtk.Window.__init__(self,gtk.WINDOW_TOPLEVEL)
         gtk.window_set_default_icon_from_file( get_xdg_pixmap_file("listen.png") )
         
         self.set_title("Listen")
         
+        Listen.__window__ = self
+        
+        utils.set_main_window(self)
+        
         if config.get("window","x")=="-1":
             self.set_position(gtk.WIN_POS_CENTER)
         else:
@@ -128,11 +129,11 @@ class Listen(gtk.Window,Logger):
         Player.connect("paused",self.swap_menu_play,Player,("Play"),gtk.STOCK_MEDIA_PLAY,"listen_tray_pause.png")
         Player.connect("stopped",self.swap_menu_play,Player,("Play"),gtk.STOCK_MEDIA_PLAY,"listen_tray.png")
         
-        self.tray = TrayIcon(self)
+        self.tray = TrayIcon()
 
         self.osd = Osd(self.tray)
         self.notify = Notify(self.tray)
-        self.dbus_service = ListenDBus(self)
+        self.dbus_service = ListenDBus()
 
         self.mmkeys = MMKeys()
 
@@ -279,8 +280,8 @@ class Listen(gtk.Window,Logger):
     def open_file2_win(self,w):
         uri = WinFile().run()
         if uri:
-           self.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
-           async_parse_uris( [uri], True, True,
+            self.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+            async_parse_uris( [uri], True, True,
                     self.playlist_ui.playlist.play_uris, pos = None, sort = True)
 
     def open_file_win(self,w):
@@ -305,10 +306,10 @@ class Listen(gtk.Window,Logger):
         ListenAbout()
     
     def open_pref_dialog(self,w):
-        PreferenceDialog(self,self.osd)
+        PreferenceDialog()
         
     def open_plugins_dialog(self,w):
-        PluginsPreferenceDialog(self)
+        PluginsPreferenceDialog()
     
     def player_control(self,action):
         name = action.get_name()
@@ -377,12 +378,12 @@ class Listen(gtk.Window,Logger):
               <menuitem action="PlayerPlaylist"/>   
               <menuitem action="Full"/>   
               <menuitem action="Party"/>
-              <separator />
+              <!--separator />
               <menu action="BrowserView">
                   <menuitem action="browserview0"/>
                   <menuitem action="browserview1"/>
                   <menuitem action="browserview2"/>
-              </menu>
+              </menu-->
             </menu>
             <menu action="Control">
               <menuitem action="playpause"/>
@@ -445,15 +446,17 @@ class Listen(gtk.Window,Logger):
                       ('random_reorder', stock.SHUFFLE, _('_Shuffle'), "<control>u","", self.playlist_ui.playlist.random_reorder),
                       
                      ])
-                     
+        """             
         browser_value = int(config.get("browser","view"))
         
+
         def on_change_browser(widget,radiobtn):
             config.set("browser","view","%d"%radiobtn.get_current_value())
-                    
+        
         ag.add_radio_actions([('browserview0', None, _('Artist and album'), None,None,0),
                                        ('browserview1', None, _('Genre and artist'), None,None,1),
                                        ('browserview2', None, _('Genre, artist and album'), None,None,2)],browser_value, on_change_browser)
+        """
                      
         def on_change_view(widget,radiobtn):
             self.change_view(radiobtn.get_current_value())
@@ -501,4 +504,3 @@ class Listen(gtk.Window,Logger):
         self.add_accel_group(self.ui.get_accel_group())
         
         return self.ui.get_widget("/MenuBar")
-
