@@ -20,14 +20,9 @@
 #
 ###
 
-import os
 
 import gtk
-import gobject
 
-from config import config
-
-from helper import Dispatcher
 from action_manager import ActionManager
 from player import Player
 
@@ -127,7 +122,7 @@ class ListenMenuBar(gtk.HBox):
         self.__hide_action()
         actions = ActionManager.get_actions(song)
         for action in actions:
-            position, types, widget, pack_end = action
+            _position, _types, widget, pack_end = action
             if type(widget) == tuple:
                 stock, func = widget
                 btn = gtk.Button()
