@@ -64,7 +64,7 @@ class Osd(object):
         frame.set_label_widget(label)
         return frame
 
-    def PluginPreferences(self, parent=None):
+    def PluginPreferences(self):
         w = gtk.VBox()
         w.set_border_width(6)
         """w.set_title(_("OSD Preferences"))
@@ -152,6 +152,7 @@ class Osd(object):
 
 
         b = gtk.VBox()
+        parent = utils.get_main_window()
         if parent.notify.dbus_notify:
             b.pack_start(check_noti,False,False)
         b.pack_start(check_osd,False,False)
@@ -270,7 +271,7 @@ class Osd(object):
         # Refresh OSD panel.
         self.__show_panel()
 
-    def __init__(self,tray):
+    def __init__(self, tray):
         Player.connect("instant-new-song",lambda player,song: self.show_osd(song))
         tray.eventbox.connect("enter-notify-event", self.on_mouse_over)
         tray.eventbox.connect("leave-notify-event", self.on_mouse_out)
@@ -288,7 +289,7 @@ class Osd(object):
             except: config.set("osd", "osd_" + key, value)
 
         color_str = config.get("osd", "osd_colors")
-        for i in [len(config.get("osd", "osd_colors").split()),4]:
+        for __ in [len(config.get("osd", "osd_colors").split()),4]:
             if len(config.get("osd", "osd_colors").split()) < 4:
                 color_str += " #000000"
 
@@ -310,7 +311,7 @@ class Osd(object):
         if self.__id_tray:
             try:gobject.source_remove(self.__id_tray)
             except:pass
-            self.__id_tray==None
+            self.__id_tray = None
         
     def show_osd(self, song,top=None,left=None):
         if config.get("osd","enable")=="false" or song is None: return
