@@ -21,11 +21,6 @@
 ###
 
 import gtk
-import gobject
-import pango
-from config import config
-import stock
-
  
 class ColumnBase(gtk.TreeViewColumn):
     def __init__(self, r, tag, title, width):
@@ -70,7 +65,7 @@ class TextColumn(ColumnBase):
         self.r.set_property("font",new_font) 
 
     def __set_text(self,column, cell, model, iter):
-        song = value = model[iter][0]
+        song = model[iter][0]
         text = song.get_str(self.tag).replace("<###>",", ")
         cell.set_property("text",text)
 
