@@ -22,7 +22,6 @@
 
 import gtk,gobject
 import stock
-import utils
 
 from vfs import move_to_trash
 from helper import Dispatcher
@@ -30,9 +29,7 @@ from logger import Logger
 
 from widget.dialog import WindowConfirmation
 from widget.song_editor import SongEditor
-from widget.misc import SimpleMenu
 from widget.cover import CoverWindow
-from song import Song
 
 from library import ListenDB
 
@@ -156,7 +153,7 @@ class _SongMenuManager(gobject.GObject,Logger):
                 w = WindowConfirmation(text)
                 if w.run() == gtk.RESPONSE_ACCEPT:
                     BackgroundDeleteSongsOperation(songs, True)
-                w.destroy()
+                w.delete_thyself()
             elif id_menu == "edit":
                 SongEditor(list(songs))
             elif id_menu == "change_cover":
