@@ -24,7 +24,8 @@
 import gtk
 import gobject
 import pango
-import traceback
+
+import utils 
 
 from config import config
 
@@ -54,6 +55,14 @@ CATEGORIE_INFO={
         }
 
 
+from source.local import LocalSource
+from source.playlistlocal import LocalPlaylistSource
+from source.wikipedia import WikipediaSource
+from source.lyrics import LyricsSource
+from source.audiocd import AudioCDSource
+from source.lastfm import LastFmRadioSource
+from source.podcast import PodcastSource
+
 class SourceManager(Manager):
     Kinds = [Source]
 
@@ -138,11 +147,8 @@ class SourceUI(gtk.VBox,Logger):
         
         self.pane.set_position(int(config.get("window","pos_organizer")))
 
-        self.sm = SourceManager(  get_xdg_lib_dirs("source"),_("Source Plugins"))
         self.enable_source_obj = {}
         self.last_selected = None
-        self.sm.scan()
-        self.refresh()
 
         Dispatcher.connect("edit-source",self.on_edition_demand)
         Dispatcher.connect("edit-playlist",self.edit_playlist)
@@ -150,8 +156,25 @@ class SourceUI(gtk.VBox,Logger):
         Dispatcher.connect("select-source-id",self.select_source_id)
 
         Dispatcher.connect("source-updated",self.populate)
+
+        self.static_source_obj = {
+		    "local":LocalPlaylistSource(),
+		    "localplaylist":LocalSource(),
+		    "wikipedia":WikipediaSource(),
+		    "lyrics":LyricsSource(),
+		    "audiocd":AudioCDSource(),
+		    "lastfm":LastFmRadioSource(),
+		    "podcast":PodcastSource(),
+        }
+        self.populate(init=True) 
+
+    @utils.threaded
+    def load(self):
+        self.sm = SourceManager(  get_xdg_lib_dirs("plugins/source"),_("Source Plugins"))
+        self.sm.scan()
         self.sm.connect("plugin-enabled",self.refresh)
         self.sm.connect("plugin-disabled",self.refresh)
+        gobject.idle_add(self.refresh)
     
     def __set_cell_background(self, cell, is_group, is_active):
         style = self.tree.get_style()
@@ -180,7 +203,6 @@ class SourceUI(gtk.VBox,Logger):
             cell.set_property("editable",False)
         else:
             path = model.get_path(iter)
-            source = model[path][0]
             item = model[path][1]
             cell.set_property("markup",item.label)
             cell.set_property("editable",item.editable)
@@ -195,7 +217,6 @@ class SourceUI(gtk.VBox,Logger):
             cell.set_property("pixbuf",None)
         else:
             path = model.get_path(iter)
-            source = model[path][0]
             item = model[path][1]
             icon = self.tree.render_icon(stock_id=item.stock,size=gtk.ICON_SIZE_MENU,detail=None)
             cell.set_property("visible",True)
@@ -247,7 +268,7 @@ class SourceUI(gtk.VBox,Logger):
                     self.loginfo("%s\t\talready loaded",name)
             elif self.enable_source_obj.has_key(name):
                 source = self.enable_source_obj[name]
-                source.destroy()
+                source.delete_thyself()
                 del self.enable_source_obj[name]
                 import gc
                 gc.collect()
@@ -262,10 +283,10 @@ class SourceUI(gtk.VBox,Logger):
         self.loginfo("*** SOURCE REFRESH END ***")
         self.loginfo("=========================================================")
 
-        self.populate(init=True) 
+        self.populate()
 
     def save(self):
-        for source in self.enable_source_obj.values():
+        for source in self.get_all_sources():
             source.save()
         iter = self.tree.get_selection().get_selected()
         if not iter or not iter[1]: path=0
@@ -288,7 +309,14 @@ class SourceUI(gtk.VBox,Logger):
                         break
                 except StopIteration:
                     break
-            
+
+    def get_all_sources(self):
+        """ return a list of all active sources """
+        objs = self.static_source_obj.values()
+        objs.extend(self.enable_source_obj.values())
+        return objs
+
+
     def populate(self,helper=None,*param,**kwargs):
         model = self.tree.get_model()   
         model.clear()
@@ -298,14 +326,16 @@ class SourceUI(gtk.VBox,Logger):
         iter_to_select = None
         
         for child in self.box_source.get_children():
-            self.box_source.remove(child)    
-        previous_item = None
-        slist = [(CATEGORIE_INFO.get(s.categorie)[0], s.categorie,s.display_index,s) for s in self.enable_source_obj.values()]
+            self.box_source.remove(child)  
+        
+        objs = self.get_all_sources()
+
+        slist = [(CATEGORIE_INFO.get(s.categorie)[0], s.categorie,s.display_index,s) for s in objs]
         slist.sort()
         
         cur_categorie = None
         iter_cur_categorie = None
-        for pos, categorie, display_index,source in slist:
+        for _pos, categorie, _display_index,source in slist:
             for item in source.get_items():
                 if categorie != cur_categorie:
                     self.loginfo("create categorie %s for %s",CATEGORIE_INFO.get(categorie)[1],item)
@@ -325,7 +355,6 @@ class SourceUI(gtk.VBox,Logger):
                     self.last_selected = item
                     iter_to_select = iter
 
-                previous_item = item
     
         self.tree.expand_all()
         if not self.last_selected and len(model) > 0:
@@ -350,9 +379,9 @@ class SourceUI(gtk.VBox,Logger):
     def on_selection(self,treeselection):  
         model,iter = treeselection.get_selected()
         if iter!=None and model[iter][0]!=None : 
-            
-            childs = self.box_source.get_children()    
+              
             """
+            childs = self.box_source.get_children()   
             if len(childs)>0:
                 self.box_source.remove(childs[0])    
             self.box_source.pack_start(model[iter][1].widget,True,True)
@@ -394,8 +423,7 @@ class SourceUI(gtk.VBox,Logger):
     def on_edition(self,cell,path, new_text):
         if self.tree.get_model()[path][1].on_edition(new_text):
             self.invalide_node(self.tree,path)
-            #self.tree.get_model()[path][2] = new_text
-            
+            self.populate()
         
     def on_activated(self,treeview, path, view_column):
         model = treeview.get_model()
@@ -420,7 +448,7 @@ class SourceUI(gtk.VBox,Logger):
         
         drop_info = self.tree.get_dest_row_at_pos(x, y)
         if drop_info:
-            path, position = drop_info
+            path, _position = drop_info
             path = path[0]
             #if position == gtk.TREE_VIEW_DROP_AFTER:
             #    path += 1
@@ -450,7 +478,7 @@ class SourceUI(gtk.VBox,Logger):
         
 
     def on_key_press(self, widget, event):
-        model, row = self.tree.get_selection().get_selected()
+        _model, row = self.tree.get_selection().get_selected()
         if row!=None and self.tree.get_model()[row][1]:
             item = self.tree.get_model()[row][1]
             return item.on_key_press(event)
@@ -460,7 +488,7 @@ class SourceUI(gtk.VBox,Logger):
     def on_drag_data_get(self,treeview, context, selection, info, timestamp):
         self.is_in_drag_motion = False
         
-        model, row = self.tree.get_selection().get_selected()
+        _model, row = self.tree.get_selection().get_selected()
         if self.real_selected_row : row = self.real_selected_row
         self.real_selected_row = None
         if row!=None:
@@ -506,7 +534,7 @@ class SourceUI(gtk.VBox,Logger):
     def __button_press(self, w,event):
         if event.button == 3:
             x, y = map(int, [event.x, event.y])
-            try: path, col, cellx, celly = self.tree.get_path_at_pos(x, y)
+            try: path, col, _cellx, _celly = self.tree.get_path_at_pos(x, y)
             except TypeError: 
                 self.__popup_default_menu()
                 return True
@@ -520,7 +548,7 @@ class SourceUI(gtk.VBox,Logger):
             return True
         elif False and event.button == 1:
             x, y = map(int, [event.x, event.y])
-            try: path, col, cellx, celly = self.tree.get_path_at_pos(x, y)
+            try: path, col, _cellx, _celly = self.tree.get_path_at_pos(x, y)
             except TypeError:
                 return False
             model = self.tree.get_model()
@@ -546,9 +574,9 @@ class SourceUI(gtk.VBox,Logger):
         menu = gtk.Menu()
         first = True
 
-        slist = [(s.display_index,s) for s in self.enable_source_obj.values()]
+        slist = [(s.display_index,s) for s in self.get_all_sources()]
         slist.sort()
-        for pos,source in slist:
+        for _pos,source in slist:
             items = source.get_default_menu()
             if items:
                 if not first: menu.append(gtk.SeparatorMenuItem())
