@@ -33,25 +33,24 @@ from player import Player
 from helper import Dispatcher
 from stock import add_stock
 
-if os.environ.get("LISTEN_NO_TRAY",0) == 0:
+if os.environ.get("LISTEN_NO_TRAY", 0) == 0:
     try: 
-        from widget.gtktrayicon import TrayIcon as Tray
+        from widget.gtktrayicon import TrayIcon as Tray #@UnusedImport
     except: 
         try:
-            from  egg.trayicon import TrayIcon as Tray
-        except: 
+            from  egg.trayicon import TrayIcon as Tray #@Reimport
+        except:  
             Tray = None
 else:
     Tray = None
 
 class TrayIcon(gobject.GObject):
-    def __init__(self,window):
-        super(TrayIcon,self).__init__()
+    def __init__(self):
+        super(TrayIcon, self).__init__()
 
-        self.win = window
-        Player.connect("played",self.on_play)
-        Player.connect("paused",self.on_pause)
-        Player.connect("stopped",self.on_pause)
+        Player.connect("played", self.on_play)
+        Player.connect("paused", self.on_pause)
+        Player.connect("stopped", self.on_pause)
 
         self.eventbox = gtk.EventBox()
 
@@ -61,8 +60,8 @@ class TrayIcon(gobject.GObject):
             self.tray.add(self.eventbox)
 
 
-        self.eventbox.connect("button_press_event", self.on_button_press_event )
-        self.eventbox.connect("scroll-event",self.on_scroll_event)
+        self.eventbox.connect("button_press_event", self.on_button_press_event)
+        self.eventbox.connect("scroll-event", self.on_scroll_event)
         
         self.tray_image = gtk.Image()
         self.eventbox.add(self.tray_image)
@@ -93,11 +92,11 @@ class TrayIcon(gobject.GObject):
         self.uimanager.add_ui_from_string(menu_ui)
 
         def get_vol_i18n(vol):
-            return (vol == 0) and _("Mute") or "%d%%"%vol
+            return (vol == 0) and _("Mute") or "%d%%" % vol
 
         try: 
-            icon = gtk.IconSet(gtk.icon_theme_get_default().load_icon("stock_volume",-1,gtk.ICON_LOOKUP_USE_BUILTIN))
-            add_stock("stock_volume","Volume", icon)
+            icon = gtk.IconSet(gtk.icon_theme_get_default().load_icon("stock_volume", -1, gtk.ICON_LOOKUP_USE_BUILTIN))
+            add_stock("stock_volume", "Volume", icon)
         except:
             pass
         actiongroup = gtk.ActionGroup('Listen')
@@ -105,31 +104,31 @@ class TrayIcon(gobject.GObject):
                                  ('pause', gtk.STOCK_MEDIA_PAUSE, _('_Pause'), None, _('Pause'), self.player_control),
                                  ('stop', gtk.STOCK_MEDIA_STOP, _('Stop'), None, _('Stop'), self.player_control),
                                  ('next', gtk.STOCK_MEDIA_NEXT, _('_Next'), None, _('Next'), self.player_control),
-                                 ('previous', gtk.STOCK_MEDIA_PREVIOUS, _('_Previous'), None, _('Previous'),self.player_control),
+                                 ('previous', gtk.STOCK_MEDIA_PREVIOUS, _('_Previous'), None, _('Previous'), self.player_control),
                                  ('volume', "stock_volume", _('_Volume'), None, _('Volume'), None),
                                  ('quit', gtk.STOCK_QUIT, _('_Quit'), None, _('Quit Listen'), lambda w: Dispatcher.quit()) 
-                                 ] + [ ("vol_%d"%i, None, get_vol_i18n(i) , None, get_vol_i18n(i), self.volume_control ) for i in [ 0, 25, 50, 75, 100 ] ]
+                                 ] + [ ("vol_%d" % i, None, get_vol_i18n(i) , None, get_vol_i18n(i), self.volume_control) for i in [ 0, 25, 50, 75, 100 ] ]
                                 )
 
         self.uimanager.insert_action_group(actiongroup, 1)
         #self.add_accel_group(accelgroup)
         self.pause = self.uimanager.get_action("/TrayIconMenu/pause")
         self.pause.set_visible(False)
-        self.play =  self.uimanager.get_action("/TrayIconMenu/play")
+        self.play = self.uimanager.get_action("/TrayIconMenu/play")
         self.menu = self.uimanager.get_widget("/TrayIconMenu")
-        self.menu.connect("selection-done",self.on_selection_done)
-        self.show_menu=False
+        self.menu.connect("selection-done", self.on_selection_done)
+        self.show_menu = False
         
         
-        gtk.quit_add(0,self.cacher)
+        gtk.quit_add(0, self.cacher)
 
     def set_tray_icon(self, filename):
-        self.tray_image.set_from_file( get_xdg_pixmap_file(filename) )
+        self.tray_image.set_from_file(get_xdg_pixmap_file(filename))
         mask = self.tray_image.get_pixbuf().render_pixmap_and_mask()[1]
         self.eventbox.shape_combine_mask(mask, 0, 0)
 
     def volume_control(self, action):
-        value = int(action.get_name().replace("vol_",""))
+        value = int(action.get_name().replace("vol_", ""))
         Dispatcher.volume(float(value) / 100)
         
     def player_control(self, action):
@@ -138,22 +137,22 @@ class TrayIcon(gobject.GObject):
             name = "playpause"
         getattr(Player, name)()
 
-    def on_delete(self,win,event):
+    def on_delete(self, win, event):
         pass
 
     def update_tooltips(self):
-        if config.get("osd","enable")=="false":
+        if config.get("osd", "enable") == "false":
             s = Player.song
             if s:
                 text = ""            
                 text += s.get_str("title")
                 if s.get("artist"):
-                    text += " - "+s.get("artist")
+                    text += " - " + s.get("artist")
                 text += "\n"
                 if Player.is_paused():
-                    text += _("Paused")+", "
+                    text += _("Paused") + ", "
                 value = Player.get_position()
-                text += utils.duration_to_string(value, "00:00", 1)+" "+_("of")+" "+utils.duration_to_string(s.get("#duration"),"00:00")
+                text += utils.duration_to_string(value, "00:00", 1) + " " + _("of") + " " + utils.duration_to_string(s.get("#duration"), "00:00")
             else:
                 text = _("No Playing")
         else:
@@ -161,21 +160,22 @@ class TrayIcon(gobject.GObject):
         self.eventbox.set_tooltip_text(text)
         return True
 
-    def on_scroll_event(self,widget,event):
-        self.win.menubar.vol.emit("scroll-event",event)
+    def on_scroll_event(self, widget, event):
+        win = utils.get_main_window()
+        win.menubar.vol.emit("scroll-event", event)
 
-    def on_selection_done(self,widget):
-        self.show_menu=False
+    def on_selection_done(self, widget):
+        self.show_menu = False
 
-    def on_pause(self,player):
+    def on_pause(self, player):
         self.pause.set_visible(False)
         self.play.set_visible(True)
 
-    def on_play(self,player):
+    def on_play(self, player):
         self.pause.set_visible(True)
         self.play.set_visible(False)
         
-    def position_menu(self,menu):
+    def position_menu(self, menu):
         #Grab from deskbar applet
         align_to = self.eventbox
         direction = self.eventbox.get_direction()
@@ -220,11 +220,12 @@ class TrayIcon(gobject.GObject):
             if event.state == gtk.gdk.CONTROL_MASK:
                 Player.previous()
             else:
-                if self.win.get_property('visible'):
-                    if self.win.is_active():
+                win = utils.get_main_window()
+                if win.get_property('visible'):
+                    if win.is_active():
                         self.cacher()
                     else:
-                        self.win.present()
+                        win.present()
                 else:
                     self.montrer()
 
@@ -235,26 +236,28 @@ class TrayIcon(gobject.GObject):
             if event.state == gtk.gdk.CONTROL_MASK:
                 Player.next()
             else:
-                self.show_menu=True
+                self.show_menu = True
                 #Player.osd.hide_osd(None,None)
-                self.menu.popup(None,None,self.position_menu,event.button,event.time)
+                self.menu.popup(None, None, self.position_menu, event.button, event.time)
 
 
     def cacher(self):
-        if self.win.window:
-            event = self.win.window.get_state()
+        win = utils.get_main_window()
+        if win.window:
+            event = win.window.get_state()
             if event == gtk.gdk.WINDOW_STATE_MAXIMIZED:
-                config.set("window","state","maximized")
+                config.set("window", "state", "maximized")
             else:
-                config.set("window","state","normal")
-            self.win.hide_all()
+                config.set("window", "state", "normal")
+            win.hide_all()
 
     def montrer(self):
-        self.win.move(int(config.get("window","x")),int(config.get("window","y")))
-        window_state = config.get("window","state")
+        win = utils.get_main_window()
+        win.move(int(config.get("window", "x")), int(config.get("window", "y")))
+        window_state = config.get("window", "state")
         if window_state == "maximized" :
-            self.win.maximize()
+            win.maximize()
         if window_state == "normal":
-            self.win.unmaximize()
-        self.win.show_all()
+            win.unmaximize()
+        win.show_all()
 
