@@ -43,7 +43,7 @@ class MultiDragTreeview(gtk.TreeView,Logger):
         if event.button == 1: return self.__block_selection(event)
         if event.button == 3:
             x, y = map(int, [event.x, event.y])
-            try: path, col, cellx, celly = self.get_path_at_pos(x, y)
+            try: path, col, _cellx, _celly = self.get_path_at_pos(x, y)
             except TypeError:
                 self.emit('popup-empty-menu')    
                 return True
@@ -58,7 +58,7 @@ class MultiDragTreeview(gtk.TreeView,Logger):
 
     def __block_selection(self, event):
         x, y = map(int, [event.x, event.y])
-        try: path, col, cellx, celly = self.get_path_at_pos(x, y)
+        try: path, _col, _cellx, _celly = self.get_path_at_pos(x, y)
         except TypeError: return True
         self.grab_focus()
         selection = self.get_selection()
@@ -78,12 +78,12 @@ class MultiDragTreeview(gtk.TreeView,Logger):
             self.__pending_event = None
             if oldevent != [event.x, event.y]: return True
             x, y = map(int, [event.x, event.y])
-            try: path, col, cellx, celly = self.get_path_at_pos(x, y)
+            try: path, col, _cellx, _celly = self.get_path_at_pos(x, y)
             except TypeError: return True
             self.set_cursor(path, col, 0)
 
     def __begin(self, ctx):
-        model, paths = self.get_selection().get_selected_rows()
+        _model, paths = self.get_selection().get_selected_rows()
         MAX = 3
         if paths:
             icons = map(self.create_row_drag_icon, paths[:MAX])
